@@ -1,78 +1,37 @@
 package Mail::Milter::Authentication;
-use 5.20.0;
+# ABSTRACT: A Perl Mail Authentication Milter
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: A Perl Mail Authentication Milter
-our $VERSION = '2.20210105.2'; # VERSION
+use base 'Net::Server::PreFork';
+our $VERSION = '2.20180318'; # VERSION
+
+
+use English qw{ -no_match_vars };
+use ExtUtils::Installed;
+use JSON;
+use Mail::Milter::Authentication::Config qw{ get_config };
+use Mail::Milter::Authentication::Constants qw{ :all };
 use Mail::Milter::Authentication::Handler;
 use Mail::Milter::Authentication::Metric;
 use Mail::Milter::Authentication::Protocol::Milter;
 use Mail::Milter::Authentication::Protocol::SMTP;
-use Email::Sender::Simple qw(try_to_sendmail);
-use Email::Simple::Creator;
-use Email::Simple;
-use ExtUtils::Installed;
-use Log::Dispatchouli;
+use Module::Load;
+use Module::Loaded;
 use Net::DNS::Resolver;
 use Net::IP;
 use Proc::ProcessTable;
-use base 'Mail::Milter::Authentication::Net::ServerPatches';
+use Sys::Syslog qw{:standard :macros};
+
 use vars qw(@ISA);
 
-
-{
-    my $LOGGER;
-    sub logger {
-
-        return $LOGGER if $LOGGER;
-        my $config = get_config();
-
-        my $MYARGS = {
-            'ident' => $Mail::Milter::Authentication::Config::IDENT,
-            'to_stderr' => 0, # handled elsewhere
-            'log_pid' => 1,
-            'facility' => LOG_MAIL,
-        };
-        if ( exists $config->{ 'log_dispatchouli' } ) {
-            $MYARGS = $config->{ 'log_dispatchouli' };
-        }
-
-        $LOGGER = Log::Dispatchouli->new( $MYARGS );
-        $LOGGER->log('Logging instantiated');
-        return $LOGGER;
-    }
-}
-
-sub _warn($msg) {
+sub _warn {
+    my ( $msg ) = @_;
     my @parts = split "\n", $msg;
     foreach my $part ( @parts ) {
         next if $part eq q{};
         print STDERR scalar(localtime) . ' ' . $Mail::Milter::Authentication::Config::IDENT . "[$PID] $part\n";
     }
-}
-
-
-sub preload_modules($self,$from,$matching) {
-    my $installed = ExtUtils::Installed->new( 'skip_cwd' => 1 );
-    my $path_matching = $matching;
-    $path_matching =~ s/::/\//g;
-    foreach my $module ( grep { /$from/ } $installed->modules() ) {
-        FILE:
-        foreach my $file ( grep { /$path_matching\/\w+\.pm$/ } $installed->files( $module ) ) {
-            next FILE if ! -e $file;
-            my ( $module ) = reverse split '/', $file;
-            $module =~ s/\.pm$//;
-            $module = join( '::', $matching, $module );
-            if ( ! is_loaded( $module ) ) {
-                $self->logdebug( "Preloading Module $module" );
-                load $module;
-            }
-            else {
-                $self->logdebug( "Preloading Module $module already loaded" );
-            }
-        }
-    }
+    return;
 }
 
 
@@ -92,27 +51,12 @@ sub get_installed_handlers {
 }
 
 
-sub write_to_log_hook($self,$priority,$line,@) {
-    my $log_priority = $priority == 0 ? 'debug'
-                     : $priority == 1 ? 'info'
-                     : $priority == 2 ? 'notice'
-                     : $priority == 3 ? 'warning'
-                     : $priority == 4 ? 'error'
-                     : 'debug';
-    logger()->log( { 'level' => $log_priority }, $line );
-}
+sub pre_loop_hook {
+    my ( $self ) = @_;
 
+    $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':master';
 
-sub idle_loop_hook($self,@) {
-    $self->{'metric'}->parent_metric_update( $self );
-}
-
-
-sub pre_loop_hook($self,@) {
-    $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':parent';
-
-    $self->preload_modules( 'Net::DNS', 'Net::DNS::RR' );
-    $self->{'metric'} = Mail::Milter::Authentication::Metric->new($self);
+    $self->{'metric'} = Mail::Milter::Authentication::Metric->new();
 
     # Load handlers
     my $config = get_config();
@@ -151,13 +95,17 @@ sub pre_loop_hook($self,@) {
         open( STDERR, '>>', $config->{'error_log'} ) || die "Cannot open errlog [$!]";
         open( STDOUT, '>>', $config->{'error_log'} ) || die "Cannot open errlog [$!]";
     }
+
+    return;
+
 }
 
 
-sub run_n_children_hook($self,@) {
+sub run_n_children_hook {
+    my ( $self ) = @_;
+
     # Load handlers
     my $config = get_config();
-    $self->{metric}->re_register_metrics;
     foreach my $name ( @{$config->{'load_handlers'}} ) {
 
         my $package = "Mail::Milter::Authentication::Handler::$name";
@@ -167,12 +115,13 @@ sub run_n_children_hook($self,@) {
         }
 
     }
+
+    return;
 }
 
 
 sub child_init_hook {
-    my ( $self,$arg ) = @_;
-    srand();
+    my ( $self ) = @_;
 
     my $config = get_config();
     $self->{'config'} = $config;
@@ -187,19 +136,13 @@ sub child_init_hook {
         }
     }
 
-    $arg = '' if !defined $arg;
-    if ( $arg eq 'dequeue' ) {
-        $self->loginfo( "Dequeue process $PID starting up" );
-        $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':dequeue';
-    }
-    else {
-        $self->loginfo( "Child process $PID starting up" );
-        $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':starting';
-    }
+    $self->loginfo( "Child process $PID starting up" );
+    $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':starting';
 
     my $base;
     if ( $config->{'protocol'} eq 'milter' ) {
         $base = 'Mail::Milter::Authentication::Protocol::Milter';
+
     }
     elsif ( $config->{'protocol'} eq 'smtp' ) {
         $base = 'Mail::Milter::Authentication::Protocol::SMTP';
@@ -217,9 +160,7 @@ sub child_init_hook {
            $protocol &= ~SMFIP_NOBODY;
            $protocol &= ~SMFIP_NOHDRS;
            $protocol &= ~SMFIP_NOEOH;
-           $protocol |= SMFIP_HDR_LEADSPC;
         $self->{'protocol'} = $protocol;
-        $self->{'headers_include_space'} = 0;
 
         my $callback_flags = SMFI_CURR_ACTS|SMFIF_CHGBODY|SMFIF_QUARANTINE|SMFIF_SETSENDER;
         $self->{'callback_flags'} = $callback_flags;
@@ -241,46 +182,32 @@ sub child_init_hook {
     $self->{'object_maker'}   = $object_maker;
 
     $self->setup_handlers();
-    $self->{'metric'}->set_versions( $self );
-
-    $self->{'handler'}->{'_Handler'}->metric_count( 'forked_children_total', {}, 1 ) unless $arg eq 'dequeue';
 
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':waiting(0)';
+    return;
 }
 
 
 sub child_finish_hook {
-    my ( $self,$arg ) = @_;
+    my ($self) = @_;
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':exiting';
-    $arg = '' if !defined $arg;
-    if ( $arg eq 'dequeue' ) {
-        $self->loginfo( "Dequeue process $PID shutting down" );
-    }
-    else {
-        $self->loginfo( "Child process $PID shutting down" );
-        eval {
-            $self->{'handler'}->{'_Handler'}->metric_count( 'reaped_children_total', {}, 1 );
-        };
-    }
+    $self->loginfo( "Child process $PID shutting down" );
+    $self->{'handler'}->{'_Handler'}->metric_count( 'reaped_children_total', {}, 1 );
+    $self->{'handler'}->{'_Handler'}->metric_send();
     $self->destroy_objects();
+    return;
 }
 
 
-sub pre_server_close_hook($self,@) {
+sub pre_server_close_hook {
+    my ($self) = @_;
     $self->loginfo( 'Server closing down' );
+    return;
 }
 
 
-sub dequeue($self,@) {
-    my $config = $self->{ 'config' };
-    my $seconds = $config->{'dequeue_timeout'} // 300;
-    $self->{handler}->{_Handler}->set_overall_timeout( $seconds * 1000000 );
-    $self->{handler}->{_Handler}->top_dequeue_callback();
-    $self->{handler}->{_Handler}->clear_overall_timeout();
-}
-
-
-sub get_client_proto($self,@) {
+sub get_client_proto {
+    my ( $self ) = @_;
     my $socket = $self->{server}{client};
     if ($socket->isa("Net::Server::Proto")) {
         my $proto = $socket->NS_proto;
@@ -301,28 +228,34 @@ sub get_client_proto($self,@) {
     }
 
     $self->logerror( "Could not determine connection protocol: " . ref($socket) );
+
+    return;
 }
 
 
-sub get_client_port($self,@) {
+sub get_client_port {
+    my ( $self ) = @_;
     my $socket = $self->{server}{client};
     return $socket->sockport();
 }
 
 
-sub get_client_host($self,@) {
+sub get_client_host {
+    my ( $self ) = @_;
     my $socket = $self->{server}{client};
     return $socket->sockhost();
 }
 
 
-sub get_client_path($self,@) {
+sub get_client_path {
+    my ( $self ) = @_;
     my $socket = $self->{server}{client};
     return $socket->hostpath();
 }
 
 
-sub get_client_details($self,@) {
+sub get_client_details {
+    my ( $self ) = @_;
     my $proto = lc $self->get_client_proto();
     if ( $proto eq 'tcp' ) {
         return 'inet:' . $self->get_client_port();
@@ -330,10 +263,46 @@ sub get_client_details($self,@) {
     elsif ( $proto eq 'unix' ) {
         return 'unix:' . $self->get_client_path();
     }
+    return;
 }
 
 
-sub process_request($self,@) {
+sub child_is_talking_hook {
+    my ( $self, $socket ) = @_;
+
+    my $request;
+    my $raw_request;
+
+    eval {
+        $raw_request = <$socket>;
+        return if ! $raw_request;
+        $request = decode_json( $raw_request );
+    };
+    if ( my $error = $@ ) {
+        warn "Error $error reading from child";
+        return;
+    }
+    else {
+
+        if ( ! $request ) {
+            warn "Ignoring Invalid child request: $raw_request;";
+            return;
+        }
+        $request =~ s/[\n\r]+$//;
+        if ( $request->{ 'method' } eq 'METRIC.GET' ) {
+            $self->{'metric'}->master_handler( $request, $socket, $self );
+        }
+        if ( $request->{ 'method' } eq 'METRIC.COUNT' ) {
+            $self->{'metric'}->master_handler( $request, $socket, $self );
+        }
+    }
+
+    return;
+}
+
+
+sub process_request {
+    my ( $self ) = @_;
     my $config = $self->{'config'};
 
     my $metric_type;
@@ -371,10 +340,13 @@ sub process_request($self,@) {
 
     my $count = $self->{'count'};
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':waiting(' . $count . ')';
+    return;
 }
 
 
-sub process_main($self,@) {
+sub process_main {
+    my ( $self ) = @_;
+
     $self->{'count'}++;
     my $count = $self->{'count'};
     my $config = $self->{'config'};
@@ -383,19 +355,16 @@ sub process_main($self,@) {
     $self->logdebug( 'Processing request ' . $self->{'count'} );
     $self->{'socket'} = $self->{'server'}->{'client'};
 
-    $self->{'tracelog'} = [];
-
     $self->protocol_process_request();
 
     # Call close callback
     $self->{'handler'}->{'_Handler'}->top_close_callback();
     if ( $self->{'handler'}->{'_Handler'}->{'exit_on_close'} ) {
-        my $error = $self->{'handler'}->{'_Handler'}->{'exit_on_close_error'} // 'no reason given';
-        $self->send_exception_email($error);
-        $self->fatal('exit_on_close requested - '.$error);
+        $self->{'metric'}->send( $self );
+        $self->fatal('exit_on_close requested');
     }
 
-    $self->{'tracelog'} = [];
+    $self->{'metric'}->send( $self );
 
     if ( $config->{'debug'} ) {
         my $process_table = Proc::ProcessTable->new();
@@ -414,107 +383,14 @@ sub process_main($self,@) {
     delete $self->{'handler'}->{'_Handler'}->{'return_code'};
     delete $self->{'socket'};
     $self->logdebug( 'Request processing completed' );
+    return;
 }
 
 
-sub send_exception_email {
-    my ( $self, $error ) = @_;
-
-    if ( $self->{'handler'}->{'_Handler'}->{'suppress_error_emails'} ) {
-        return;
-    }
-
-    my $config         = get_config();
-    my $errors_to      = $config->{'errors_to'} || return;
-    my $errors_from    = $config->{'errors_from'} || return;
-    my $errors_headers = $config->{'errors_headers'} || {};
-
-    my $email = "Authentication Milter " . $Mail::Milter::Authentication::Config::IDENT . " Error\n\n";
-    $email .= "$error\n\n";
-
-    $email .= "Child PID: $PID\n\n";
-
-    $email .= "Log:\n";
-    $email .= join( "\n", $self->{'tracelog'}->@* );
-    $email .= "\n\n";
-
-    $email .= "Processes Running\n";
-    my $ppid = $self->{'server'}->{'ppid'};
-    my $process_table = Proc::ProcessTable->new;
-    foreach my $process ( $process_table->table->@* ) {
-        next if ! ( $process->pid == $ppid || $process->ppid == $ppid );
-        my $pid = eval{ $process->pid } // '';
-        my $cmndline = eval{ $process->cmndline } // '';
-        my $size   = eval{ $process->size } // '';
-        my $rss    = eval{ $process->rss } // '';
-        my $pctmem = eval{ $process->pctmem } // '';
-        my $pctcpu = eval{ $process->pctcpu } // '';
-        $email .= "pid:$pid, $cmndline, size:$size, mem:$rss ($pctmem%), cpu: $pctcpu%\n";
-    }
-
-    my @headers;
-    foreach my $key ( sort keys $errors_headers->%* ) {
-        push @headers, $key => $errors_headers->{$key};
-    }
-    push @headers, to => $errors_to;
-    push @headers, From => $errors_from;
-    push @headers, Subject => 'Authentication Milter Error';
-    push @headers, 'X-Authentication-Milter-Error' => 'Generated Error Report';
-
-    my $emailer = Email::Simple->create(
-        header => \@headers,
-        body => $email,
-    );
-    try_to_sendmail($emailer);
-
-}
 
 
-sub send_panic_email {
-    my ( $error ) = @_;
-
-    my $config         = get_config();
-    my $errors_to      = $config->{'errors_to'} || return;
-    my $errors_from    = $config->{'errors_from'} || return;
-    my $errors_headers = $config->{'errors_headers'} || {};
-
-    my $email = "Authentication Milter " . $Mail::Milter::Authentication::Config::IDENT . " Error\n\n";
-    $email .= "$error\n\n";
-
-    $email .= "PID: $PID\n\n";
-
-    $email .= "Processes Running\n";
-    my $process_table = Proc::ProcessTable->new;
-    foreach my $process ( $process_table->table->@* ) {
-        next if ! ( $process->pid == $PID || $process->ppid == $PID );
-        my $pid = eval{ $process->pid } // '';
-        my $cmndline = eval{ $process->cmndline } // '';
-        my $size   = eval{ $process->size } // '';
-        my $rss    = eval{ $process->rss } // '';
-        my $pctmem = eval{ $process->pctmem } // '';
-        my $pctcpu = eval{ $process->pctcpu } // '';
-        $email .= "pid:$pid, $cmndline, size:$size, mem:$rss ($pctmem%), cpu: $pctcpu%\n";
-    }
-
-    my @headers;
-    foreach my $key ( sort keys $errors_headers->%* ) {
-        push @headers, $key => $errors_headers->{$key};
-    }
-    push @headers, to => $errors_to;
-    push @headers, From => $errors_from;
-    push @headers, Subject => 'Authentication Milter Error';
-    push @headers, 'X-Authentication-Milter-Error' => 'Generated Error Report';
-
-    my $emailer = Email::Simple->create(
-        header => \@headers,
-        body => $email,
-    );
-    try_to_sendmail($emailer);
-
-}
-
-
-sub get_valid_pid($pid_file) {
+sub get_valid_pid {
+    my ( $pid_file ) = @_;
     if ( ! $pid_file ) {
         return undef; ## no critic
     }
@@ -531,7 +407,7 @@ sub get_valid_pid($pid_file) {
     my $found_pid  = 0;
 
     my $process_table = Proc::ProcessTable->new();
-    foreach my $process ( $process_table->table->@* ) {
+    foreach my $process ( @{$process_table->table} ) {
         if ( $process->pid == $self_pid ) {
             if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':control' ) {
                 $found_self = 1;
@@ -539,7 +415,7 @@ sub get_valid_pid($pid_file) {
         }
         if ( $process->pid == $pid ) {
             $found_pid = 1;
-            if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':parent' ) {
+            if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':master' ) {
                 return $pid;
             }
         }
@@ -560,11 +436,8 @@ sub get_valid_pid($pid_file) {
 
 sub find_process {
     my $process_table = Proc::ProcessTable->new();
-    foreach my $process ( $process_table->table->@* ) {
-        if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':master' ) { ## Legacy naming, will be removed in later version
-            return $process->pid;
-        }
-        if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':parent' ) {
+    foreach my $process ( @{$process_table->table} ) {
+        if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':master' ) {
             return $process->pid;
         }
     }
@@ -572,7 +445,8 @@ sub find_process {
 }
 
 
-sub control($args) {
+sub control {
+    my ( $args ) = @_;
     my $pid_file = $args->{'pid_file'};
     my $command  = $args->{'command'};
 
@@ -619,15 +493,20 @@ sub control($args) {
     else {
         die 'unknown command';
     }
+
+    return;
 }
 
 
-sub start($args) {
+sub start {
+    my ($args)     = @_;
+
     local $SIG{__WARN__} = sub {
         foreach my $msg ( @_ ) {
-            logger()->log( { level => 'warning' }, "Warning: $msg" );
+            syslog( LOG_ERR, "Warning: $msg" );
             _warn( "Warning: $msg" );
         }
+        return;
     };
 
     my $config                 = get_config();
@@ -643,8 +522,6 @@ sub start($args) {
     my $max_spare_children     = $config->{'max_spare_children'}     || 20;
     my $min_spare_children     = $config->{'min_spare_children'}     || 10;
 
-    setup_config();
-
     my %srvargs;
 
     $srvargs{'no_client_stdout'} = 1;
@@ -679,11 +556,17 @@ sub start($args) {
     $srvargs{'min_spare_servers'} = $min_spare_children;
     $srvargs{'max_spare_servers'} = $max_spare_children;
 
+    $srvargs{'log_file'}          = 'Sys::Syslog';
+    $srvargs{'syslog_facility'}   = LOG_MAIL;
+    $srvargs{'syslog_ident'}      = $Mail::Milter::Authentication::Config::IDENT;
+    $srvargs{'syslog_logopt'}     = 'pid';
+    $srvargs{'syslog_logsock'}    = 'native';
+
     if ( $EUID == 0 ) {
         my $user  = $config->{'runas'};
         my $group = $config->{'rungroup'};
         if ( $user && $group ) {
-            _warn("run as user=$user group=$group");
+        _warn("run as user=$user group=$group");
             $srvargs{'user'}  = $user;
             $srvargs{'group'} = $group;
         }
@@ -793,6 +676,7 @@ sub start($args) {
                 'ipv'   => '*',
                 'proto' => 'tcp',
             };
+            $srvargs{'child_communication'} = 1;
         }
         elsif ( $type eq 'unix' ) {
             _warn(
@@ -806,6 +690,7 @@ sub start($args) {
                 'port'  => $path,
                 'proto' => 'unix',
             };
+            $srvargs{'child_communication'} = 1;
 
             if ($umask) {
                 umask ( oct( $umask ) );
@@ -830,6 +715,7 @@ sub start($args) {
             'ipv'   => '*',
             'proto' => 'tcp',
         };
+        $srvargs{'child_communication'} = 1;
         _warn( 'Metrics available on ' . $metric_host . ':' . $config->{'metric_port'} );
         _warn( 'metric_host/metric_port are depricated, please use metric_connection/metric_umask instead' );
     }
@@ -838,15 +724,6 @@ sub start($args) {
     $srvargs{'listen'} = $listen_backlog;
     $srvargs{'leave_children_open_on_hup'} = 1;
 
-    if ( $config->{'patch_net_server'} && scalar @ports == 1 ) {
-        my $error = 'Net::Server patches can not be applied when listening on a single port';
-        _warn $error;
-        die;
-    }
-
-    $srvargs{'max_dequeue'} = 1;
-    $srvargs{'check_for_dequeue'} = $config->{'check_for_dequeue'} // 60;
-
     _warn "==========";
     _warn "Starting server";
     _warn "Running with perl $PERL_VERSION";
@@ -868,64 +745,68 @@ sub start($args) {
         $error = 'unknown error' if ! $error;
         _warn "Server failed: $error";
 
-        # We exited abnormally, try and clean up
-        eval{ __PACKAGE__->close_children };
-        eval{ __PACKAGE__->post_child_cleanup_hook };
-        eval{ __PACKAGE__->shutdown_sockets };
-        sleep 10;
-
         if ( scalar @start_times >= 4 ) {
             if ( $start_times[3] > ( time() - 120 ) ) {
-                eval{ send_panic_email("Error: $error - Abandoning") };
                 _warn "Abandoning automatic restart: too many restarts in a short time";
                 last;
             }
         }
 
-        eval{ send_panic_email("Error: $error - Attempting automatic restart") };
         _warn "Attempting automatic restart";
         sleep 10;
     }
     _warn "Server exiting abnormally";
     die;
+
+    return; ## no critic
 }
 
 ##### Protocol methods
 
 
-sub fatal($self,$error) {
+sub fatal {
+    my ( $self, $error ) = @_;
     $self->logerror( "Child process $PID shutting down due to fatal error: $error" );
     die "$error\n";
 }
 
 
-sub fatal_global($self,$error) {
+sub fatal_global {
+    my ( $self, $error ) = @_;
     my $ppid = $self->{'server'}->{'ppid'};
     if ( $ppid == $PID ) {
         $self->logerror( "Global shut down due to fatal error: $error" );
     }
     else {
         $self->logerror( "Child process $PID signalling global shut down due to fatal error: $error" );
-        kill 'TERM', $ppid;
+        kill 'Term', $ppid;
     }
     die "$error\n";
 }
 
 
-sub setup_handlers($self) {
+sub setup_handlers {
+    my ( $self ) = @_;
+
     $self->logdebug( 'setup objects' );
     my $handler = Mail::Milter::Authentication::Handler->new( $self );
     $self->{'handler'}->{'_Handler'} = $handler;
 
+    $handler->metric_count( 'forked_children_total', {}, 1 );
+    $handler->metric_send();
+
     my $config = $self->{'config'};
-    foreach my $name ( $config->{'load_handlers'}->@* ) {
+    foreach my $name ( @{$config->{'load_handlers'}} ) {
         $self->setup_handler( $name );
     }
     $self->sort_all_callbacks();
+    return;
 }
 
 
-sub load_handler($self,$name) {
+sub load_handler {
+    my ( $self, $name ) = @_;
+
     ## TODO error handling here
     $self->logdebug( "Load Handler $name" );
 
@@ -937,10 +818,13 @@ sub load_handler($self,$name) {
             $self->fatal_global('Could not load handler ' . $name . ' : ' . $error);
         }
     }
+    return;
 }
 
 
-sub setup_handler($self,$name) {
+sub setup_handler {
+    my ( $self, $name ) = @_;
+
     ## TODO error handling here
     $self->logdebug( "Instantiate Handler $name" );
 
@@ -948,11 +832,13 @@ sub setup_handler($self,$name) {
     my $object = $package->new( $self );
     $self->{'handler'}->{$name} = $object;
 
-    foreach my $callback ( qw { metrics setup connect helo envfrom envrcpt header eoh body eom addheader abort close dequeue } ) {
+    foreach my $callback ( qw { setup connect helo envfrom envrcpt header eoh body eom addheader abort close } ) {
         if ( $object->can( $callback . '_callback' ) ) {
             $self->register_callback( $name, $callback );
         }
     }
+
+    return;
 }
 
 
@@ -963,26 +849,33 @@ sub destroy_handler {
     delete $self->{'handler'}->{$name}->{'thischild'};
     # Remove reference to handler
     delete $self->{'handler'}->{$name};
+    return;
 }
 
 
-sub register_callback($self,$name,$callback) {
+sub register_callback {
+    my ( $self, $name, $callback ) = @_;
     $self->logdebug( "Register Callback $name:$callback" );
     if ( ! exists $self->{'callbacks'}->{$callback} ) {
         $self->{'callbacks'}->{$callback} = [];
     }
     push @{ $self->{'callbacks'}->{$callback} }, $name;
+    return;
 }
 
 
-sub sort_all_callbacks($self) {
-    foreach my $callback ( qw { metrics setup connect helo envfrom envrcpt header eoh body eom addheader abort close dequeue } ) {
+sub sort_all_callbacks {
+    my ($self) = @_;
+    foreach my $callback ( qw { setup connect helo envfrom envrcpt header eoh body eom addheader abort close } ) {
         $self->sort_callbacks( $callback );
     }
+    return;
 }
 
 
-sub sort_callbacks($self,$callback) {
+sub sort_callbacks {
+    my ( $self, $callback ) = @_;
+
     if ( ! exists $self->{'callbacks'}->{$callback} ) {
         $self->{'callbacks'}->{$callback} = [];
     }
@@ -1001,48 +894,31 @@ sub sort_callbacks($self,$callback) {
 
     my @todo = sort @{$callbacks_ref};
     my $todo_count = scalar @todo;
-
-    # Process requirements
-    my $requirements = {};
-    foreach my $item ( @todo ) {
-        $requirements->{ $item } = [];
-        my $handler = $self->{'handler'}->{ $item };
-        my $requires_method = $callback . '_requires';
-        if ( $handler->can( $requires_method ) ) {
-            my $requires = $handler->$requires_method;
-            foreach my $require ( $requires->@* ) {
-                push @{ $requirements->{ $item } }, $require;
-            }
-        }
-    }
-    foreach my $item ( @todo ) {
-        my $handler = $self->{'handler'}->{ $item };
-        my $requires_method = $callback . '_required_before';
-        if ( $handler->can( $requires_method ) ) {
-            my $requires = $handler->$requires_method;
-            foreach my $require ( $requires->@* ) {
-                push @{ $requirements->{ $require } }, $item;
-            }
-        }
-    }
-
     while ( $todo_count ) {
         my @defer;
         foreach my $item ( @todo ) {
-            my $requires_met = 1;
-            my $requires = $requirements->{ $item };
-            foreach my $require ( $requires->@* ) {
-                if ( ! exists $added->{$require} ) {
-                    $requires_met = 0;
+            my $handler = $self->{'handler'}->{ $item };
+            my $requires_method = $callback . '_requires';
+            if ( $handler->can( $requires_method ) ) {
+                my $requires_met = 1;
+                my $requires = $handler->$requires_method;
+                foreach my $require ( @{ $requires } ) {
+                    if ( ! exists $added->{$require} ) {
+                        $requires_met = 0;
+                    }
+                }
+                if ( $requires_met == 1 ) {
+                    push @order, $item;
+                    $added->{$item} = 1;
+                }
+                else {
+                    push @defer, $item;
                 }
             }
-            if ( $requires_met == 1 ) {
+            else {
                 push @order, $item;
                 $added->{$item} = 1;
             }
-            else {
-                push @defer, $item;
-            }
         }
 
         my $defer_count = scalar @defer;
@@ -1054,22 +930,25 @@ sub sort_callbacks($self,$callback) {
     }
 
     $self->{'callbacks_list'}->{$callback} = \@order;
+    return;
 }
 
 
-sub destroy_objects($self) {
+sub destroy_objects {
+    my ( $self ) = @_;
     $self->logdebug ( 'destroy objects' );
     my $handler = $self->{'handler'}->{'_Handler'};
     if ( $handler ) {
         $handler->destroy_all_objects();
         my $config = $self->{'config'};
-        foreach my $name ( $config->{'load_handlers'}->@* )  {
+        foreach my $name ( @{$config->{'load_handlers'}} ) {
             $self->destroy_handler( $name );
         }
         delete $self->{'handler'}->{'_Handler'}->{'config'};
         delete $self->{'handler'}->{'_Handler'}->{'thischild'};
         delete $self->{'handler'}->{'_Handler'};
     }
+    return;
 }
 
 
@@ -1078,7 +957,8 @@ sub destroy_objects($self) {
 ## Logging
 
 
-sub get_queue_id($self) {
+sub get_queue_id {
+    my ( $self ) = @_;
     my $queue_id;
 
     if ( exists ( $self->{'smtp'} ) ) {
@@ -1094,7 +974,8 @@ sub get_queue_id($self) {
 }
 
 
-sub enable_extra_debugging($self) {
+sub enable_extra_debugging {
+    my ($self) = @_;
     my $config = $self->{'config'} || get_config();
     $config->{'logtoerr'} = 1;
     $config->{'debug'}    = 1;
@@ -1102,45 +983,54 @@ sub enable_extra_debugging($self) {
     $self->logerror( 'Extra debugging enabled. Child will exit on close.' );
     # We don't want to persist this, so force an exit on close state.
     $self->{'handler'}->{'_Handler'}->{'exit_on_close'} = 1;
+    return;
 }
 
 
-sub extra_debugging($self,$line) {
+sub extra_debugging {
+    my ($self,$line) = @_;
     if ( $self->{'extra_debugging'} ) {
         $self->logerror( $line );
     }
+    return;
 }
 
 
-sub logerror($self,$line) {
+sub logerror {
+    my ($self,$line) = @_;
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
     }
     _warn( $line ) if $config->{'logtoerr'};
-    logger()->log( { 'level' => 'error' }, $line );
+    syslog( LOG_ERR, $line );
+    return;
 }
 
 
-sub loginfo($self,$line) {
+sub loginfo {
+    my ($self,$line) = @_;
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
     }
     _warn( $line ) if $config->{'logtoerr'};
-    logger()->log( { 'level' => 'info' }, $line );
+    syslog( LOG_INFO, $line );
+    return;
 }
 
 
-sub logdebug($self,$line) {
+sub logdebug {
+    my ($self,$line) = @_;
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
     }
     if ( $config->{'debug'} ) {
         _warn( $line ) if $config->{'logtoerr'};
-        logger()->log( { 'level' => 'debug' }, $line );
+        syslog( LOG_DEBUG, $line );
     }
+    return;
 }
 
 1;
@@ -1157,7 +1047,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -1179,23 +1069,9 @@ A Perl Implementation of email authentication standards rolled up into a single
 
 =head1 METHODS
 
-=head2 preload_modules( $from, $matching )
-
-Preload (pre-fork) lazy loading modules.
-
-Takes a Package Name and a Base module, and loads all modules which match.
-
-=head2 I<write_to_log_hook()>
-
-Hook which runs to write logs
-
-=head2 I<idle_loop_hook()>
-
-Hook which runs in the parent periodically.
-
 =head2 I<pre_loop_hook()>
 
-Hook which runs in the parent before looping.
+Hook which runs in the master before looping.
 
 =head2 I<run_n_children_hook()>
 
@@ -1213,10 +1089,6 @@ Hook which runs when the child is about to finish.
 
 Hook which runs before the server closes.
 
-=head2 I<dequeue()>
-
-Call the dequeue handlers
-
 =head2 I<get_client_proto()>
 
 Get the protocol of the connecting client.
@@ -1237,6 +1109,10 @@ Get the path of the connecting client.
 
 Get the details of the connecting client.
 
+=head2 I<child_is_talking_hook( $sock )>
+
+Hook which runs when a child wishes to communicate with the parent.
+
 =head2 I<process_request()>
 
 Hook which runs for each request, passes control to metrics handler or process_main as appropriate.
@@ -1245,10 +1121,6 @@ Hook which runs for each request, passes control to metrics handler or process_m
 
 Method which runs for each request, sets up per request items and processes the request.
 
-=head2 I<send_exception_email()>
-
-Send an email to the administrator with details of a problem.
-
 =head2 I<fatal($error)>
 
 Log a fatal error and die in child
@@ -1319,19 +1191,13 @@ Log to the debug log.
 
 Return an array ref of installed handler modules.
 
-=head2 I<send_panic_email()>
-
-Send an email to the administrator with details of a problem.
-
-Called from the parent process if the server exits.
-
 =head2 I<get_valid_pid($pid_file)>
 
 Given a pid file, check for a valid process ID and return if valid.
 
 =head2 I<find_process()>
 
-Search the process table for an authentication_milter parent process
+Search the process table for an authentication_milter master process
 
 =head2 I<control($command)>
 
@@ -1352,7 +1218,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
