@@ -1,16 +1,16 @@
 package Mail::Milter::Authentication::Client;
-use 5.20.0;
+
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Client for connecting back to the authmilter server
-our $VERSION = '2.20210105.2'; # VERSION
-use Mail::Milter::Authentication::Net::Milter;
+our $VERSION = '2.20180318'; # VERSION
+
 use Data::Dumper;
 use Digest::MD5 qw{ md5_base64 };
 use Email::Simple;
+use English qw{ -no_match_vars };
 
-
+use Mail::Milter::Authentication::Net::Milter;
+use Mail::Milter::Authentication::Config qw{ get_config };
 
 sub new {
     my ( $class, $args ) = @_;
@@ -73,7 +73,6 @@ sub new {
     return $self;
 }
 
-
 sub r { ## no critic [Subroutines::RequireArgUnpacking]
     my $self = shift;
     my @results = @_;
@@ -118,9 +117,9 @@ sub r { ## no critic [Subroutines::RequireArgUnpacking]
             warn Dumper $result;
         }
     }
+    return;
 }
 
-
 sub insert_header {
     my ( $self, $index, $header, $value ) = @_;
     my @process_header = @{ $self->{'header_pairs'} };
@@ -138,9 +137,9 @@ sub insert_header {
         $i++;
     }
     $self->{'header_pairs'} = \@header_pairs;
+    return;
 }
 
-
 sub replace_header {
     my ( $self, $index, $header, $value ) = @_;
 
@@ -172,18 +171,18 @@ sub replace_header {
         }
     }
     $self->{'header_pairs'} = \@header_pairs;
+    return;
 }
 
-
 sub add_header {
     my ( $self, $header, $value ) = @_;
     my @header_pairs = @{ $self->{'header_pairs'} };
     push @header_pairs, $header;
     push @header_pairs, $value;
     $self->{'header_pairs'} = \@header_pairs;
+    return;
 }
 
-
 sub load_mail {
     my ( $self ) = @_;
 
@@ -202,7 +201,8 @@ sub load_mail {
     my @header_split;
 
     HEADERS:
-    foreach my $dataline ( split ( /\r?\n/, $mail_data ) ) {
+    foreach my $dataline ( split ( "\n", $mail_data ) ) {
+        $dataline =~ s/\r?\n$//;
         # Handle transparency
         if ( $dataline =~ /^\./ ) {
             $dataline = substr( $dataline, 1 );
@@ -238,9 +238,9 @@ sub load_mail {
     my $message_object = Email::Simple->new( $mail_data );
     $self->{'message_object'} = $message_object;
     $self->{'header_pairs'}   = \@header_pairs;
+    return;
 }
 
-
 sub process {
     my ( $self ) = @_;
 
@@ -327,9 +327,9 @@ sub process {
     }
 
     $self->{'result'} =  $self->{'message_object'}->as_string();
+    return;
 }
 
-
 sub result {
     my ( $self ) = @_;
     return $self->{'rejected'} if $self->{'rejected'} && $self->{'testing'};
@@ -346,11 +346,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Client - Client for connecting back to the authmilter server
+Mail::Milter::Authentication::Client
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,9 @@ Client to the Authentication Milter
 
 =head1 CONSTRUCTOR
 
-=head2 I<new( $args )>
+=over
+
+=item I<new($args)>
 
 Instantiate a new Client object
 
@@ -379,35 +381,7 @@ Instantiate a new Client object
         'mail_file'     => '/path/to/email.txt',
     });
 
-=head1 METHODS
-
-=head2 I<r()>
-
-Private method, do not call this directly
-
-=head2 I<insert_header()>
-
-Private method, do not call this directly
-
-=head2 I<replace_header()>
-
-Private method, do not call this directly
-
-=head2 I<add_header()>
-
-Private method, do not call this directly
-
-=head2 I<load_mail()>
-
-Private method, do not call this directly
-
-=head2 I<process()>
-
-Send the email to the milter and process the result.
-
-=head2 I<result()>
-
-Return the result of the milter run
+=back
 
 =head2 Arguments
 
@@ -455,6 +429,36 @@ The EMail body can also be passed as a filename.
 
 =back
 
+=head1 PUBLIC METHODS
+
+=over
+
+=item I<process()>
+
+Send the email to the milter and process the result.
+
+=item I<result()>
+
+Return the result.
+
+=back
+
+=head1 PRIVATE METHODS
+
+=over
+
+=item I<r()>
+
+=item I<insert_header()>
+
+=item I<replace_header()>
+
+=item I<add_header()>
+
+=item I<load_mail()>
+
+=back
+
 =head1 Net::Milter
 
 This project includes a modified copy of Net::Milter which is
@@ -474,7 +478,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
