@@ -1,30 +1,13 @@
 package Mail::Milter::Authentication::Constants;
 # ABSTRACT: Define and export useful constants
-use 5.20.0;
 use strict;
 use warnings;
-##use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Common constants
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Exporter';
+our $VERSION = '2.20180318'; # VERSION
 
 
 ## no critic [Modules::ProhibitAutomaticExportation]
 
-# Syslog Constants
-
-use constant LOG_DEBUG   => 7;
-use constant LOG_INFO    => 6;
-use constant LOG_NOTICE  => 5;
-use constant LOG_WARNING => 4;
-use constant LOG_ERR     => 3;
-use constant LOG_CRIT    => 2;
-use constant LOG_ALERT   => 1;
-use constant LOG_EMERG   => 0;
-use constant LOG_MAIL    => 16;
-
-# Sendmail Constants
-
 use constant SMFIA_UNKNOWN      => 'U';
 use constant SMFIA_UNIX         => 'L';
 use constant SMFIA_INET         => '4';
@@ -69,7 +52,6 @@ use constant SMFIP_NOBODY       => 0x10;
 use constant SMFIP_NOHDRS       => 0x20;
 use constant SMFIP_NOEOH        => 0x40;
 use constant SMFIP_NONE         => 0x7F;
-use constant SMFIP_HDR_LEADSPC  => 0x100000;
 
 use constant SMFIS_CONTINUE     => 100;
 use constant SMFIS_REJECT       => 101;
@@ -91,15 +73,6 @@ use constant SMFI_V2_ACTS       => SMFI_V1_ACTS|SMFIF_CHGHDRS;
 use constant SMFI_CURR_ACTS     => SMFI_V2_ACTS;
 
 our @EXPORT = qw(
-    LOG_DEBUG
-    LOG_INFO
-    LOG_NOTICE
-    LOG_WARNING
-    LOG_ERR
-    LOG_CRIT
-    LOG_ALERT
-    LOG_EMERG
-    LOG_MAIL
     SMFIA_UNKNOWN
     SMFIA_UNIX
     SMFIA_INET
@@ -141,7 +114,6 @@ our @EXPORT = qw(
     SMFIP_NOHDRS
     SMFIP_NOEOH
     SMFIP_NONE
-    SMFIP_HDR_LEADSPC
     SMFIS_CONTINUE
     SMFIS_REJECT
     SMFIS_DISCARD
@@ -162,6 +134,7 @@ our @EXPORT = qw(
 our @EXPORT_OK = ( @EXPORT );
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
 
+
 1;
 
 __END__
@@ -176,11 +149,11 @@ Mail::Milter::Authentication::Constants - Define and export useful constants
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
-Constants defined here are used in the sendmail milter protocol
+Constants defined here are used in the sendmail milter protocol.
 
 =head1 DESCRIPTION
 
@@ -192,7 +165,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
