@@ -1,11 +1,10 @@
 package Mail::Milter::Authentication::Handler::AddID;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Example handler class
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
 
 sub default_config {
     return {};
@@ -16,6 +15,7 @@ sub eom_callback {
     # On HELO
     my ( $self, $helo_host ) = @_;
     $self->append_header('X-Authentication-Milter','Header added by Authentication Milter');
+    return;
 }
 
 1;
@@ -28,11 +28,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::AddID - Example handler class
+Mail::Milter::Authentication::Handler::AddID
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -50,7 +50,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
