@@ -1,12 +1,13 @@
 package Mail::Milter::Authentication::Handler::AlignedFrom;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for Address alignment
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
 use Net::DNS;
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -46,6 +47,8 @@ sub envfrom_callback {
         $self->{ 'smtp_address'} = lc $email;
         $self->{ 'smtp_domain'} = lc $self->get_domain_from( $email );
     }
+
+    return;
 }
 
 sub header_callback {
@@ -73,16 +76,18 @@ sub header_callback {
         # If there are more than 1 then the result will be set to error in the eom callback
         # Multiple from headers should always set the result to error.
     }
+
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
-    delete $self->{ 'envfrom_count' };
     delete $self->{ 'from_header_count' };
     delete $self->{ 'header_address' };
     delete $self->{ 'header_domain' };
     delete $self->{ 'smtp_address' };
     delete $self->{ 'smtp_domain' };
+    return;
 }
 
 # error = multiple from headers present
@@ -141,9 +146,7 @@ sub eom_callback {
             my $dmarc_handler = $self->get_handler('DMARC');
             my $dmarc_object = $dmarc_handler->get_dmarc_object();
             my $org_smtp_domain   = eval{ $dmarc_object->get_organizational_domain( $self->{ 'smtp_domain' } ); };
-            $self->handle_exception( $@ );
             my $org_header_domain = eval{ $dmarc_object->get_organizational_domain( $self->{ 'header_domain' } ); };
-            $self->handle_exception( $@ );
 
             if ( $org_smtp_domain eq $org_header_domain ) {
                 $result = 'orgdomain_pass';
@@ -170,6 +173,8 @@ sub eom_callback {
     $self->add_auth_header( $header );
 
     $self->metric_count( 'alignedfrom_total', { 'result' => $result } );
+
+    return;
 }
 
 1;
@@ -182,11 +187,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::AlignedFrom - Handler class for Address alignment
+Mail::Milter::Authentication::Handler::AlignedFrom
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -202,7 +207,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
