@@ -1,11 +1,13 @@
 package Mail::Milter::Authentication::Handler::Auth;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for SMTP Auth
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -30,6 +32,7 @@ sub pre_loop_setup {
     if ( $protocol ne 'milter' ) {
         warn 'The Auth handler only works with the milter protocol';
     }
+    return;
 }
 
 sub get_auth_name {
@@ -41,6 +44,7 @@ sub get_auth_name {
 sub connect_callback {
     my ( $self, $hostname, $ip ) = @_;
     $self->{'is_authenticated'} = 0;
+    return;
 }
 
 sub envfrom_callback {
@@ -58,11 +62,13 @@ sub envfrom_callback {
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'auth' )->safe_set_value( 'pass' );
         $self->add_auth_header( $header );
     }
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_authenticated'};
+    return;
 }
 
 1;
@@ -75,11 +81,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::Auth - Handler class for SMTP Auth
+Mail::Milter::Authentication::Handler::Auth
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -95,7 +101,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
