@@ -1,25 +1,28 @@
 package Mail::Milter::Authentication::Handler::DKIM;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for DKIM
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::DKIM 1.20200824;
+our $VERSION = '2.20180318'; # VERSION
+
+use Data::Dumper;
+use English qw{ -no_match_vars };
+use Sys::Syslog qw{:standard :macros};
+
+use Mail::DKIM 0.39;
+use Mail::DKIM::Verifier 0.39;
 use Mail::DKIM::DNS;
-use Mail::DKIM::KeyValueList;
-use Mail::DKIM::Verifier;
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {
         'hide_none'         => 0,
         'hide_domainkeys'   => 0,
         'check_adsp'        => 1,
-        'show_default_adsp' => 0,
+        'show default_adsp' => 0,
         'adsp_hide_none'    => 0,
         'extra_properties'  => 0,
-        'no_strict'         => 0,
     };
 }
 
@@ -45,6 +48,7 @@ sub envfrom_callback {
     $self->{'valid_domains'} = {};
     $self->{'carry'}         = q{};
     $self->destroy_object('dkim');
+    return;
 }
 
 sub show_domainkeys {
@@ -56,37 +60,21 @@ sub show_domainkeys {
 }
 
 sub header_callback {
-    my ( $self, $header, $value, $original ) = @_;
+    my ( $self, $header, $value ) = @_;
     return if ( $self->{'failmode'} );
     my $EOL        = "\015\012";
-    my $dkim_chunk = $original . $EOL;
+    my $dkim_chunk = $header . ': ' . $value . $EOL;
     $dkim_chunk =~ s/\015?\012/$EOL/g;
     push @{$self->{'headers'}} , $dkim_chunk;
 
     if ( lc($header) eq 'dkim-signature' ) {
         $self->{'has_dkim'} = 1;
-
-        my $parsed = eval{ Mail::DKIM::KeyValueList->parse( $value ) };
-        $self->handle_exception( $@ );
-        if ( $parsed ) {
-            my $domain = $parsed->get_tag('d');
-            my $selector = $parsed->get_tag('s');
-            if ( $selector && $domain ) {
-                my $resolver = $self->get_object('resolver');
-                my $lookup = $selector.'._domainkey.'.$domain;
-                eval{ $resolver->bgsend( $lookup, 'TXT' ) };
-                $self->handle_exception( $@ );
-                $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
-                $lookup = '_adsp._domainkey.'.$domain;
-                eval{ $resolver->bgsend( $lookup, 'TXT' ) };
-                $self->handle_exception( $@ );
-                $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
-            }
-        }
     }
     if ( lc($header) eq 'domainkey-signature' ) {
         $self->{'has_dkim'} = 1 if $self->show_domainkeys();
     }
+
+    return;
 }
 
 sub eoh_callback {
@@ -108,21 +96,19 @@ sub eoh_callback {
 
         my $dkim;
         eval {
-            my $UseStrict = 1;
-            if ( $config->{ 'no_strict' } ) {
-                $UseStrict = 0;
+            $dkim = Mail::DKIM::Verifier->new();
+            # The following requires Mail::DKIM > 0.4
+            if ( $Mail::DKIM::VERSION >= 0.4 ) {
+                my $resolver = $self->get_object('resolver');
+                Mail::DKIM::DNS::resolver($resolver);
             }
-            $dkim = Mail::DKIM::Verifier->new( 'Strict' => $UseStrict );
-            my $resolver = $self->get_object('resolver');
-            Mail::DKIM::DNS::resolver($resolver);
             $self->set_object('dkim', $dkim, 1);
         };
         if ( my $error = $@ ) {
-            $self->handle_exception( $error );
             $self->log_error( 'DKIM Setup Error ' . $error );
-            $self->{'failmode'} = 1;
             $self->_check_error( $error );
             $self->metric_count( 'dkim_total', { 'result' => 'error' } );
+            $self->{'failmode'} = 1;
             delete $self->{'headers'};
             return;
         }
@@ -134,17 +120,18 @@ sub eoh_callback {
             );
         };
         if ( my $error = $@ ) {
-            $self->handle_exception( $error );
             $self->log_error( 'DKIM Headers Error ' . $error );
-            $self->{'failmode'} = 1;
             $self->_check_error( $error );
             $self->metric_count( 'dkim_total', { 'result' => 'error' } );
+            $self->{'failmode'} = 1;
         }
 
         delete $self->{'headers'};
     }
 
     $self->{'carry'} = q{};
+
+    return;
 }
 
 sub body_callback {
@@ -174,12 +161,12 @@ sub body_callback {
         $dkim->PRINT( $dkim_chunk );
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
         $self->log_error( 'DKIM Body Error ' . $error );
-        $self->{'failmode'} = 1;
         $self->_check_error( $error );
         $self->metric_count( 'dkim_total', { 'result' => 'error' } );
+        $self->{'failmode'} = 1;
     }
+    return;
 }
 
 sub eom_callback {
@@ -195,7 +182,6 @@ sub eom_callback {
     eval {
         $dkim->PRINT( $self->{'carry'} );
         $dkim->CLOSE();
-        $self->check_timeout();
 
         my $dkim_result        = $dkim->result;
         my $dkim_result_detail = $dkim->result_detail;
@@ -296,15 +282,15 @@ sub eom_callback {
                     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.d' )->safe_set_value( $signature->domain() ) );
                     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.i' )->safe_set_value( $signature->identity() ) );
                     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.b' )->safe_set_value( substr( $signature->data(), 0, 8 ) ) );
-                    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.a' )->safe_set_value( $key_type . '-' . $hash_algorithm ) );
-                    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.s' )->safe_set_value( $selector ) );
                     if ( $config->{'extra_properties'} ) {
                         $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-bits' )->safe_set_value( $key_size ) );
+                        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-keytype' )->safe_set_value( $key_type ) );
+                        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-algorithm' )->safe_set_value( $hash_algorithm ) );
+                        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-selector' )->safe_set_value( $selector ) );
                     }
                     $self->add_auth_header($header);
                 }
             }
-            $self->check_timeout();
         }
 
         # the alleged author of the email may specify how to handle email
@@ -354,18 +340,16 @@ sub eom_callback {
                         $self->add_auth_header( $header );
                     }
                 }
-                $self->check_timeout();
             }
         }
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
 
         # Also in DMARC module
         $self->log_error( 'DKIM EOM Error ' . $error );
-        $self->{'failmode'} = 1;
         $self->_check_error( $error );
         $self->metric_count( 'dkim_total', { 'result' => 'error' } );
+        $self->{'failmode'} = 1;
         return;
     }
 }
@@ -379,6 +363,7 @@ sub close_callback {
     delete $self->{'has_dkim'};
     delete $self->{'valid_domains'};
     $self->destroy_object('dkim');
+    return;
 }
 
 sub _check_error {
@@ -408,13 +393,15 @@ sub _check_error {
         $self->add_auth_header( $header );
     }
     else {
-        $self->exit_on_close( 'Unexpected DKIM Error - ' . $error );
+        $self->log_error( 'Unexpected DKIM Error - ' . $error );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dkim' )->safe_set_value( 'temperror' );
         $self->add_auth_header( $header );
         # Fill these in as they occur, but for unknowns err on the side of caution
         # and tempfail/exit
+        $self->exit_on_close();
         $self->tempfail_on_error();
     }
+    return;
 }
 
 1;
@@ -427,11 +414,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::DKIM - Handler class for DKIM
+Mail::Milter::Authentication::Handler::DKIM
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -446,7 +433,6 @@ Module for validation of DKIM and DomainKeys signatures, and application of ADSP
             "show_default_adsp" : 0,                    | Show the default ADSP result
             "adsp_hide_none"    : 0,                    | Hide auth ADSP if the result is 'none'
             "extra_properties"  : 0                     | Add extra properties (not to rfc) relating to key and selector
-            "no_strict"         : 0,                    | Ignore rfc 8301 security considerations (not recommended
         },
 
 =head1 AUTHOR
@@ -455,7 +441,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
