@@ -1,13 +1,15 @@
 package Mail::Milter::Authentication::Handler::IPRev;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for IPRev
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
 use Net::DNS;
 use Net::IP;
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -42,11 +44,12 @@ sub _dns_error {
           . ' with '
           . $error );
     }
+    return;
 }
 
 sub connect_requires {
     my ($self) = @_;
-    my @requires = qw{ LocalIP TrustedIP };
+    my @requires = qw{ LocalIP TrustedIP Auth };
     return \@requires;
 }
 
@@ -54,6 +57,7 @@ sub connect_callback {
     my ( $self, $hostname, $ip ) = @_;
     return if ( $self->is_local_ip_address() );
     return if ( $self->is_trusted_ip_address() );
+    return if ( $self->is_authenticated() );
     my $ip_address = $self->ip_address();
     my $i1         = $ip;
     my $resolver = $self->get_object('resolver');
@@ -192,15 +196,10 @@ sub connect_callback {
     foreach my $domain ( sort keys %$ptr_list ) {
         foreach my $address ( sort @{ $ptr_list->{ $domain } } ) {
             my $i2 = Net::IP->new($address);
-            if ( !$i2 ) {
-                $self->log_error( 'IPRev: Could not parse IP '.$address );
-            }
-            else {
-                my $is_overlap = $i1->overlaps($i2) || 0;
-                if ( $is_overlap == $IP_IDENTICAL ) {
-                    $domain =~ s/\.$//;
-                    push @match_list, $domain;
-                }
+            my $is_overlap = $i1->overlaps($i2) || 0;
+            if ( $is_overlap == $IP_IDENTICAL ) {
+                $domain =~ s/\.$//;
+                push @match_list, $domain;
             }
         }
     }
@@ -210,7 +209,7 @@ sub connect_callback {
         my $comment = join( ',', @error_list );
         $self->dbgout( 'IPRevCheck', "fail - $comment", LOG_DEBUG );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'iprev' )->safe_set_value( 'fail' );
-        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.remote-ip' )->safe_set_value( $ip_address ) );
+        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.iprev' )->safe_set_value( $ip_address ) );
         $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( $comment ) );
         $self->add_c_auth_header($header);
         $self->metric_count( 'iprev_total', { 'result' => 'fail'} );
@@ -221,11 +220,13 @@ sub connect_callback {
         $self->{'verified_ptr'} = $comment;
         $self->dbgout( 'IPRevCheck', "pass - $comment", LOG_DEBUG );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'iprev' )->safe_set_value( 'pass' );
-        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.remote-ip' )->safe_set_value( $ip_address ) );
+        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.iprev' )->safe_set_value( $ip_address ) );
         $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( $comment ) );
         $self->add_c_auth_header($header);
         $self->metric_count( 'iprev_total', { 'result' => 'pass'} );
     }
+
+    return;
 }
 
 sub _address_for_domain {
@@ -267,6 +268,7 @@ sub _address_for_domain {
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'verified_ptr'};
+    return;
 }
 
 1;
@@ -279,11 +281,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::IPRev - Handler class for IPRev
+Mail::Milter::Authentication::Handler::IPRev
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -299,7 +301,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
