@@ -1,11 +1,13 @@
 package Mail::Milter::Authentication::Handler::LocalIP;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for Local IP Connections
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -64,11 +66,13 @@ sub connect_callback {
         $self->{'is_local_ip_address'} = 1;
         $self->metric_count( 'localip_connect_total' );
     }
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_local_ip_address'};
+    return;
 }
 
 1;
@@ -81,11 +85,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::LocalIP - Handler class for Local IP Connections
+Mail::Milter::Authentication::Handler::LocalIP
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -101,7 +105,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
