@@ -1,11 +1,13 @@
 package Mail::Milter::Authentication::Handler::PTR;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for PTR checking
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -54,10 +56,12 @@ sub helo_callback {
     my $result = $found_match ? 'pass' : 'fail';
     $self->dbgout( 'PTRMatch', $result, LOG_DEBUG );
     my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-ptr' )->safe_set_value( $result );
-    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.helo' )->safe_set_value( $helo_host ) );
-    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.ptr' )->safe_set_value( $domains ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-ptr-helo' )->safe_set_value( $helo_host ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-ptr-lookup' )->safe_set_value( $domains ) );
     $self->add_c_auth_header( $header );
     $self->metric_count( 'ptr_total', { 'result' => $result} );
+
+    return;
 }
 
 1;
@@ -70,11 +74,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::PTR - Handler class for PTR checking
+Mail::Milter::Authentication::Handler::PTR
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -92,7 +96,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
