@@ -1,11 +1,14 @@
 package Mail::Milter::Authentication::Handler::SPF;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for SPF
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
+
 use Mail::SPF;
 
 sub default_config {
@@ -39,7 +42,6 @@ sub setup_callback {
             );
         };
         if ( my $error = $@ ) {
-            $self->handle_exception( $error );
             $self->log_error( 'SPF Object Setup Error ' . $error );
         }
         $thischild->{'object'}->{$name} = {
@@ -47,6 +49,7 @@ sub setup_callback {
             'destroy' => 0,
         };
     });
+    return;
 }
 
 sub register_metrics {
@@ -67,6 +70,7 @@ sub helo_callback {
     my ( $self, $helo_host ) = @_;
     $self->{'failmode'} = 0;
     $self->{'helo_name'} = $helo_host;
+    return;
 }
 
 sub envfrom_callback {
@@ -120,10 +124,6 @@ sub envfrom_callback {
         );
 
         my $spf_result = $spf_server->process($spf_request);
-        my $spf_results = $self->get_object('spf_results');
-        $spf_results = [] if ! $spf_results;
-        push @$spf_results, $spf_result;
-        $self->set_object('spf_results',$spf_results,1);
 
         my $result_code = $spf_result->code();
 
@@ -137,7 +137,6 @@ sub envfrom_callback {
                     my $dmarc_object = $dmarc_handler->get_dmarc_object();
                     if ( $domain ) {
                         my $org_domain = eval{ $dmarc_object->get_organizational_domain( $domain ); };
-                        $self->handle_exception( $@ );
                         if ( $org_domain ne $domain ) {
                             $auth_domain = $org_domain;
                             $spf_request = Mail::SPF::Request->new(
@@ -149,10 +148,6 @@ sub envfrom_callback {
                                 'helo_identity'    => $self->{'helo_name'},
                             );
                             $spf_result = $spf_server->process($spf_request);
-                            my $spf_results = $self->get_object('spf_results');
-                            $spf_results = [] if ! $spf_results;
-                            push @$spf_results, $spf_result;
-                            $self->set_object('spf_results',$spf_results,1);
                             $result_code = $spf_result->code();
                         }
                     }
@@ -164,7 +159,7 @@ sub envfrom_callback {
 
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'spf' )->safe_set_value( $result_code );
         if ( $auth_domain ) {
-            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.authdomain' )->safe_set_value( $auth_domain ) );
+            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-authority-domain' )->safe_set_value( $auth_domain ) );
         }
         $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.mailfrom' )->safe_set_value( $self->get_address_from( $env_from ) ) );
         $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.helo' )->safe_set_value( $self->{ 'helo_name' } ) );
@@ -190,13 +185,14 @@ sub envfrom_callback {
         }
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
         $self->log_error( 'SPF Error ' . $error );
-        $self->{'failmode'} = 1;
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'spf' )->safe_set_value( 'temperror' );
         $self->add_auth_header($header);
         $self->metric_count( 'spf_total', { 'result' => 'error' } );
+        $self->{'failmode'} = 1;
     }
+
+    return;
 }
 
 sub close_callback {
@@ -206,7 +202,7 @@ sub close_callback {
     delete $self->{'dmarc_result'};
     delete $self->{'failmode'};
     delete $self->{'helo_name'};
-    $self->destroy_object('spf_results');
+    return;
 }
 
 1;
@@ -219,11 +215,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::SPF - Handler class for SPF
+Mail::Milter::Authentication::Handler::SPF
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -245,7 +241,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
