@@ -1,11 +1,10 @@
 package Mail::Milter::Authentication::Handler::Sanitize;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for Removing headers
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
 
 sub default_config {
     return {
@@ -31,68 +30,51 @@ sub is_hostname_mine {
     my ( $self, $check_hostname ) = @_;
     my $config = $self->handler_config();
 
-    return 0 if ! defined $check_hostname;
+    my $hostname = $self->get_my_hostname();
+    my ($check_for) = $hostname =~ /^[^\.]+\.(.*)/;
 
     if ( exists( $config->{'hosts_to_remove'} ) ) {
         foreach my $remove_hostname ( @{ $config->{'hosts_to_remove'} } ) {
-            if ( $check_hostname =~ m/^(.*\.)?\Q${remove_hostname}\E$/i ) {
+            if (
+                substr( lc $check_hostname, ( 0 - length($remove_hostname) ) ) eq
+                lc $remove_hostname )
+            {
                 return 1;
             }
         }
     }
 
-    my $hostname = $self->get_my_hostname();
-    my ($check_for) = $hostname =~ /^[^\.]+\.(.*)/;
-    if ( $check_hostname =~ m/^(.*\.)?\Q${check_for}\E$/i ) {
+    if (
+        substr( lc $check_hostname, ( 0 - length($check_for) ) ) eq
+        lc $check_for )
+    {
         return 1;
     }
-
-    my $authserv_id = $self->get_my_authserv_id();
-    if ( fc( $check_hostname ) eq fc( $authserv_id ) ) {
-        return 1;
-    }
-
     return 0;
 }
 
 sub remove_auth_header {
     my ( $self, $index ) = @_;
-    $self->metric_count( 'sanitize_remove_total', {'header'=>'authentication-results'} );
+    $self->metric_count( 'sanitize_remove_total' );
     if ( !exists( $self->{'remove_auth_headers'} ) ) {
         $self->{'remove_auth_headers'} = [];
     }
     push @{ $self->{'remove_auth_headers'} }, $index;
-}
-
-sub get_headers_to_remove {
-    my ( $self ) = @_;
-    my @headers = qw{ X-Disposition-Quarantine };
-    return \@headers;
+    return;
 }
 
 sub envfrom_callback {
     my ( $self, $env_from ) = @_;
     delete $self->{'auth_result_header_index'};
     delete $self->{'remove_auth_headers'};
-
-    my $headers = {};
-    foreach my $header ( sort @{ $self->get_headers_to_remove() } ) {
-        $headers->{ lc $header } = {
-            'index'  => 0,
-            'silent' => 1,
-        };
-    }
-    $self->{'header_hash'} = $headers;
+    return;
 }
 
 sub header_callback {
     my ( $self, $header, $value ) = @_;
     my $config = $self->handler_config();
-
     return if ( $self->is_trusted_ip_address() );
     return if ( lc $config->{'remove_headers'} eq 'no' );
-
-    # Sanitize Authentication-Results headers
     if ( lc $header eq 'authentication-results' ) {
         if ( !exists $self->{'auth_result_header_index'} ) {
             $self->{'auth_result_header_index'} = 0;
@@ -115,54 +97,27 @@ sub header_callback {
             }
         }
     }
-
-    # Sanitize other headers
-    foreach my $remove_header ( sort @{ $self->get_headers_to_remove() } ) {
-        next if ( lc $remove_header ne lc $header );
-        $self->{'header_hash'}->{ lc $header }->{'index'} = $self->{'header_hash'}->{ lc $header }->{'index'} + 1;
-        $self->metric_count( 'sanitize_remove_total', {'header'=> lc $header} );
-
-        if ( ! $self->{'header_hash'}->{ lc $header }->{'silent'} ) {
-            my $forged_header =
-              '(Received ' . $remove_header . ' header removed by '
-              . $self->get_my_hostname()
-              . ')' . "\n"
-              . '    '
-              . $value;
-            $self->append_header( 'X-Received-' . $remove_header,
-                $forged_header );
-        }
-    }
+    return;
 }
 
 sub eom_callback {
     my ($self) = @_;
     my $config = $self->handler_config();
     return if ( lc $config->{'remove_headers'} eq 'no' );
-
     if ( exists( $self->{'remove_auth_headers'} ) ) {
         foreach my $index ( reverse @{ $self->{'remove_auth_headers'} } ) {
             $self->dbgout( 'RemoveAuthHeader', $index, LOG_DEBUG );
             $self->change_header( 'Authentication-Results', $index, q{} );
         }
     }
-
-    foreach my $remove_header ( sort @{ $self->get_headers_to_remove() } ) {
-        my $max_index = $self->{'header_hash'}->{ lc $remove_header }->{'index'};
-        if ( $max_index ) {
-            for ( my $index = $max_index; $index > 0; $index-- ) {
-                $self->dbgout( 'RemoveHeader', "$remove_header $index", LOG_DEBUG );
-                $self->change_header( $remove_header, $index, q{} );
-            }
-        }
-    }
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'remove_auth_headers'};
     delete $self->{'auth_result_header_index'};
-    delete $self->{'header_hash'};
+    return;
 }
 
 1;
@@ -175,11 +130,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::Sanitize - Handler class for Removing headers
+Mail::Milter::Authentication::Handler::Sanitize
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -206,7 +161,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
