@@ -1,14 +1,18 @@
 package Mail::Milter::Authentication::Handler::SenderID;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for SenderID
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::Milter::Authentication::Handler::SPF;
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
+
 use Mail::SPF;
 
+use Mail::Milter::Authentication::Handler::SPF;
+
 sub default_config {
     return {
         'hide_none' => 1,
@@ -38,6 +42,7 @@ sub register_metrics {
 sub helo_callback {
     my ( $self, $helo_host ) = @_;
     $self->{'helo_name'} = $helo_host;
+    return;
 }
 
 sub envfrom_callback {
@@ -46,6 +51,7 @@ sub envfrom_callback {
     return if ( $self->is_trusted_ip_address() );
     return if ( $self->is_authenticated() );
     delete $self->{'from_header'};
+    return;
 }
 
 sub header_callback {
@@ -56,6 +62,7 @@ sub header_callback {
     if ( lc $header eq 'from' ) {
         $self->{'from_header'} = $value;
     }
+    return;
 }
 
 sub eoh_callback {
@@ -113,19 +120,20 @@ sub eoh_callback {
         }
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
         $self->log_error( 'SENDERID Error ' . $error );
         $self->metric_count( 'senderid_total', { 'result' => 'error' } );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'senderid' )->safe_set_value( 'temperror' );
         $self->add_auth_header($header);
         return;
     }
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'from_header'};
     delete $self->{'helo_name'};
+    return;
 }
 
 1;
@@ -138,11 +146,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::SenderID - Handler class for SenderID
+Mail::Milter::Authentication::Handler::SenderID
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -160,7 +168,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
