@@ -1,11 +1,12 @@
 package Mail::Milter::Authentication::Handler::Size;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for message size metrics
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Data::Dumper;
+use English qw{ -no_match_vars };
+use Sys::Syslog qw{:standard :macros};
 
 sub default_config {
     return {};
@@ -21,7 +22,6 @@ sub grafana_rows {
 sub register_metrics {
     return {
         'size_total' => 'The number of emails processed for Size',
-        'size_header_bytes_added_total' => 'The header size added to emails processed for Size',
         'size_header_bytes_total' => 'The header size of emails processed for Size',
         'size_body_bytes_total' => 'The body size of emails processed for Size',
     };
@@ -31,44 +31,37 @@ sub envfrom_callback {
     my ( $self, $env_from )  = @_;
     $self->{'headersize'} = 0;
     $self->{'bodysize'} = 0;
+    return;
 }
 
 sub header_callback {
     my ( $self, $header, $value ) = @_;
     $self->{ 'headersize' } = $self->{ 'headersize' } + length( $header . ': ' . $value ) + 2;
+
+    return;
 }
 
 sub body_callback {
     my ( $self, $body_chunk ) = @_;
     $self->{ 'bodysize' } = $self->{ 'bodysize' } + length ( $body_chunk );
+    return;
 }
 
 sub eom_callback {
     my ($self) = @_;
+
     $self->metric_count( 'size_total', {}, 1 );
     $self->metric_count( 'size_header_bytes_total', {}, $self->{ 'headersize' } );
     $self->metric_count( 'size_body_bytes_total', {}, $self->{ 'bodysize' } );
+
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
-
-    my $top_handler = $self->get_top_handler();
-    if ( exists( $top_handler->{'pre_headers'} ) ) {
-        foreach my $header ( @{ $top_handler->{'pre_headers'} } ) {
-            my $size = length( $header->{'field'} ) + length ( $header->{'value'} ) + 3;
-            $self->metric_count( 'size_header_bytes_added_total', { where => 'pre', 'header' => $header->{'field'} }, $size );
-        }
-    }
-    if ( exists( $top_handler->{'add_headers'} ) ) {
-        foreach my $header ( @{ $top_handler->{'add_headers'} } ) {
-            my $size = length( $header->{'field'} ) + length ( $header->{'value'} ) + 3;
-            $self->metric_count( 'size_header_bytes_added_total', { where => 'add', 'header' => $header->{'field'} }, $size );
-        }
-    }
-
     delete $self->{'bodysize'};
     delete $self->{'headersize'};
+    return;
 }
 
 1;
@@ -81,11 +74,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::Size - Handler class for message size metrics
+Mail::Milter::Authentication::Handler::Size
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -101,7 +94,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
