@@ -1,11 +1,13 @@
 package Mail::Milter::Authentication::Handler::TLS;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for TLS
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -30,12 +32,7 @@ sub pre_loop_setup {
     if ( $protocol eq 'smtp' ) {
         warn 'When in smtp mode, the TLS handler requires the MTA to write TLS data into the first Received header.';
     }
-}
-
-sub connect_callback {
-    my ( $self ) = @_;
-    # Reset state on a connection
-    delete $self->{'is_encrypted'};
+    return;
 }
 
 sub envfrom_callback {
@@ -54,19 +51,17 @@ sub envfrom_callback {
 
     if ($version) {
         $self->dbgout( 'EncryptedAs', "$version, $cipher, $bits bits$trusted", LOG_INFO );
-        $self->{'is_encrypted'} = 1;
 
         my $metric_data = {};
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-tls' )->safe_set_value( 'pass' );
-        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.version' )->safe_set_value( $version ) );
-        $metric_data->{ 'version' } = $version;
+        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'version' )->safe_set_value( $version ) );
 
         if ( $cipher ) {
-            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.cipher' )->safe_set_value( $cipher ) );
+            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'cipher' )->safe_set_value( $cipher ) );
             $metric_data->{ 'cipher' } = $cipher;
         }
         if ( $bits ) {
-            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.bits' )->safe_set_value( $bits ) );
+            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'bits' )->safe_set_value( $bits ) );
             $metric_data->{ 'bits' } = $bits;
         }
         $metric_data->{ 'trusted' } = $trusted ? 1 : 0;
@@ -75,9 +70,7 @@ sub envfrom_callback {
 
         $self->add_auth_header( $header );
     }
-    else {
-        $self->{'is_encrypted'} = 0;
-    }
+    return;
 }
 
 sub header_callback {
@@ -107,19 +100,17 @@ sub header_callback {
 
     if ($version) {
         $self->dbgout( 'EncryptedAs', "$version, $cipher, $bits bits", LOG_INFO );
-        $self->{'is_encrypted'} = 1;
 
         my $metric_data = {};
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-tls' )->safe_set_value( 'pass' );
-        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.version' )->safe_set_value( $version ) );
-        $metric_data->{ 'version' } = $version;
+        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'version' )->safe_set_value( $version ) );
 
         if ( $cipher ) {
-            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.cipher' )->safe_set_value( $cipher ) );
+            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'cipher' )->safe_set_value( $cipher ) );
             $metric_data->{ 'cipher' } = $cipher;
         }
         if ( $bits ) {
-            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'smtp.bits' )->safe_set_value( $bits ) );
+            $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'bits' )->safe_set_value( $bits ) );
             $metric_data->{ 'bits' } = $bits;
         }
 
@@ -127,20 +118,14 @@ sub header_callback {
 
         $self->add_auth_header( $header );
     }
-}
 
-sub eoh_callback {
-    my ( $self ) = @_;
-    my $protocol = Mail::Milter::Authentication::Config::get_config()->{'protocol'};
-    return if $protocol ne 'smtp';
-    return if defined $self->{'is_encrypted'};
-    $self->{'is_encrypted'} = 0;
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'first_header_read'};
-    delete $self->{'is_encrypted'};
+    return;
 }
 
 1;
@@ -153,11 +138,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::TLS - Handler class for TLS
+Mail::Milter::Authentication::Handler::TLS
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -173,7 +158,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
