@@ -1,12 +1,14 @@
 package Mail::Milter::Authentication::Handler::TrustedIP;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for Trusted IP addresses
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+our $VERSION = '2.20180318'; # VERSION
+
 use Net::IP;
+use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {
@@ -28,20 +30,15 @@ sub is_trusted_ip_address {
     my $trusted = 0;
     foreach my $trusted_ip ( @{ $config->{'trusted_ip_list'} } ) {
         my $trusted_obj = Net::IP->new($trusted_ip);
-        if ( !$trusted_obj ) {
-            $self->log_error( 'TrustedIP: Could not parse Trusted IP '.$trusted_ip );
-        }
-        else {
-            my $is_overlap = $ip_obj->overlaps($trusted_obj) || 0;
-            if (
-                   $is_overlap == $IP_A_IN_B_OVERLAP
-                || $is_overlap == $IP_B_IN_A_OVERLAP     # Should never happen
-                || $is_overlap == $IP_PARTIAL_OVERLAP    # Should never happen
-                || $is_overlap == $IP_IDENTICAL
-              )
-            {
-                $trusted = 1;
-            }
+        my $is_overlap = $ip_obj->overlaps($trusted_obj) || 0;
+        if (
+               $is_overlap == $IP_A_IN_B_OVERLAP
+            || $is_overlap == $IP_B_IN_A_OVERLAP     # Should never happen
+            || $is_overlap == $IP_PARTIAL_OVERLAP    # Should never happen
+            || $is_overlap == $IP_IDENTICAL
+          )
+        {
+            $trusted = 1;
         }
     }
     return $trusted;
@@ -63,11 +60,13 @@ sub connect_callback {
         $self->{'is_trusted_ip_address'} = 1;
         $self->metric_count( 'trustedip_connect_total' );
     }
+    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_trusted_ip_address'};
+    return;
 }
 
 1;
@@ -80,11 +79,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::TrustedIP - Handler class for Trusted IP addresses
+Mail::Milter::Authentication::Handler::TrustedIP
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -107,7 +106,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
