@@ -1,14 +1,19 @@
 package Mail::Milter::Authentication::Handler::XGoogleDKIM;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for Google specific DKIM
-our $VERSION = '2.20210105.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::DKIM 1.20200824;
-use Mail::DKIM::DNS;
+our $VERSION = '2.20180318'; # VERSION
+
+use Data::Dumper;
+use English qw{ -no_match_vars };
+use Sys::Syslog qw{:standard :macros};
+
+use Mail::DKIM;
 use Mail::DKIM::Verifier;
+use Mail::DKIM::DNS;
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {
@@ -36,13 +41,14 @@ sub envfrom_callback {
     $self->{'has_dkim'}     = 0;
     $self->{'carry'}        = q{};
     $self->destroy_object('xgdkim');
+    return;
 }
 
 sub header_callback {
-    my ( $self, $header, $value, $original ) = @_;
+    my ( $self, $header, $value ) = @_;
     return if ( $self->{'failmode'} );
     my $EOL        = "\015\012";
-    my $dkim_chunk = $original . $EOL;
+    my $dkim_chunk = $header . ': ' . $value . $EOL;
     $dkim_chunk =~ s/\015?\012/$EOL/g;
 
     if ( lc($header) eq 'dkim-signature' ) {
@@ -60,16 +66,9 @@ sub header_callback {
         $x_dkim_chunk =~ s/\015?\012/$EOL/g;
         push @{$self->{'headers'}} , $x_dkim_chunk;
         $self->{'has_dkim'} = 1;
-        my ($domain) = $value =~ /d=([^;]*);/;
-        my ($selector) = $value =~ /s=([^;]*);/;
-        my $resolver = $self->get_object('resolver');
-        if ( $selector && $domain ) {
-            my $lookup = $selector.'._domainkey.'.$domain;
-            eval{ $resolver->bgsend( $lookup, 'TXT' ) };
-            $self->handle_exception( $@ );
-            $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
-        }
     }
+
+    return;
 }
 
 sub eoh_callback {
@@ -92,16 +91,18 @@ sub eoh_callback {
         my $dkim;
         eval {
             $dkim = Mail::DKIM::Verifier->new();
-            my $resolver = $self->get_object('resolver');
-            Mail::DKIM::DNS::resolver($resolver);
+            # The following requires Mail::DKIM > 0.4
+            if ( $Mail::DKIM::VERSION >= 0.4 ) {
+                my $resolver = $self->get_object('resolver');
+                Mail::DKIM::DNS::resolver($resolver);
+            }
             $self->set_object('xgdkim', $dkim, 1);
         };
         if ( my $error = $@ ) {
-            $self->handle_exception( $error );
             $self->log_error( 'XGoogleDKIM Setup Error ' . $error );
-            $self->{'failmode'} = 1;
             $self->_check_error( $error );
             $self->metric_count( 'xgoogledkim_total', { 'result' => 'error' } );
+            $self->{'failmode'} = 1;
             delete $self->{'headers'};
             return;
         }
@@ -113,17 +114,18 @@ sub eoh_callback {
             );
         };
         if ( my $error = $@ ) {
-            $self->handle_exception( $error );
             $self->log_error( 'XGoogleDKIM Headers Error ' . $error );
-            $self->{'failmode'} = 1;
             $self->_check_error( $error );
             $self->metric_count( 'xgoogledkim_total', { 'result' => 'error' } );
+            $self->{'failmode'} = 1;
         }
 
         delete $self->{'headers'};
     }
 
     $self->{'carry'} = q{};
+
+    return;
 }
 
 sub body_callback {
@@ -153,12 +155,12 @@ sub body_callback {
         $dkim->PRINT( $dkim_chunk );
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
         $self->log_error( 'XGoogleDKIM Body Error ' . $error );
-        $self->{'failmode'} = 1;
         $self->_check_error( $error );
         $self->metric_count( 'xgoogledkim_total', { 'result' => 'error' } );
+        $self->{'failmode'} = 1;
     }
+    return;
 }
 
 sub eom_callback {
@@ -242,12 +244,12 @@ sub eom_callback {
 
     };
     if ( my $error = $@ ) {
-        $self->handle_exception( $error );
+
         # Also in DMARC module
         $self->log_error( 'XGoogleDKIM EOM Error ' . $error );
-        $self->{'failmode'} = 1;
         $self->_check_error( $error );
         $self->metric_count( 'xgoogledkim_total', { 'result' => 'error' } );
+        $self->{'failmode'} = 1;
         return;
     }
 }
@@ -260,6 +262,7 @@ sub close_callback {
     delete $self->{'carry'};
     delete $self->{'has_dkim'};
     $self->destroy_object('xgdkim');
+    return;
 }
 
 sub _check_error {
@@ -283,13 +286,15 @@ sub _check_error {
         $self->add_auth_header( $header );
     }
     else {
-        $self->exit_on_close( 'Unexpected XGoogleDKIM Error - ' . $error );
+        $self->log_error( 'Unexpected XGoogleDKIM Error - ' . $error );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-google-dkim' )->safe_set_value( 'temperror' );
         $self->add_auth_header( $header );
         # Fill these in as they occur, but for unknowns err on the side of caution
         # and tempfail/exit
+        $self->exit_on_close();
         $self->tempfail_on_error();
     }
+    return;
 }
 
 1;
@@ -302,11 +307,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::XGoogleDKIM - Handler class for Google specific DKIM
+Mail::Milter::Authentication::Handler::XGoogleDKIM
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -324,7 +329,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
