@@ -1,10 +1,9 @@
 package Mail::Milter::Authentication::Metric::Grafana;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Class for Grafana dashboards
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20180318'; # VERSION
+
+use JSON;
 
 sub get_json {
     my ( $self, $file ) = @_;
@@ -48,7 +47,7 @@ sub get_dashboard {
         }
     }
 
-    my $J = JSON::XS->new();
+    my $J = JSON->new();
     $J->pretty();
     $J->canonical();
 
@@ -69,11 +68,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Metric::Grafana - Class for Grafana dashboards
+Mail::Milter::Authentication::Metric::Grafana
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -137,7 +136,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
