@@ -3,8 +3,7 @@ package Mail::Milter::Authentication::Net::Milter;
 use strict;
 use Carp;
 use vars qw($DEBUG);
-# ABSTRACT: Local modified copy of Net::Milter
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20180318'; # VERSION
 $DEBUG=0;
 
 use constant PROTOCOL_NEGATION => 0;
@@ -719,11 +718,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Net::Milter - Local modified copy of Net::Milter
+Mail::Milter::Authentication::Net::Milter
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -1091,7 +1090,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
