@@ -1,12 +1,13 @@
 package Mail::Milter::Authentication::Protocol::Milter;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Milter protocol handling
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20180318'; # VERSION
+
+use English qw{ -no_match_vars };
 use Net::IP;
 
+use Mail::Milter::Authentication::Constants qw{ :all };
+
 sub register_metrics {
     return {
         'mail_processed_total' => 'Number of emails processed',
@@ -40,6 +41,8 @@ sub protocol_process_request {
         $self->milter_process_command( $command, $data );
 
     }
+
+    return;
 }
 
 sub milter_process_command {
@@ -52,8 +55,7 @@ sub milter_process_command {
 
     if ( $command eq SMFIC_CONNECT ) {
         my ( $host, $ip ) = $self->milter_process_connect( $buffer );
-        $handler->remap_connect_callback( $host, $ip );
-        $returncode = $handler->top_connect_callback( $host, $handler->{'ip_object'} );
+        $returncode = $handler->top_connect_callback( $host, $ip );
     }
     elsif ( $command eq SMFIC_ABORT ) {
         $returncode = $handler->top_abort_callback();
@@ -80,17 +82,11 @@ sub milter_process_command {
     }
     elsif ( $command eq SMFIC_HELO ) {
         my $helo = $self->milter_split_buffer( $buffer );
-        $handler->remap_helo_callback( @$helo );
-        $returncode = $handler->top_helo_callback( $handler->{'helo_name'} );
+        $returncode = $handler->top_helo_callback( @$helo );
     }
     elsif ( $command eq SMFIC_HEADER ) {
         my $header = $self->milter_split_buffer( $buffer );
         if ( @$header == 1 ) { push @$header , q{}; };
-        my $original = join( $self->{'headers_include_space'} ? ':': ': ', @$header );
-        push @$header, $original;
-        $header->[1] =~ s/^\s+//;
-        $header->[0] =~ s/^\s+//;
-        $header->[0] =~ s/\s+$//;
         $returncode = $handler->top_header_callback( @$header );
     }
     elsif ( $command eq SMFIC_MAIL ) {
@@ -110,7 +106,6 @@ sub milter_process_command {
             pack('NNN', 2, $actions_reply, $protocol_reply)
         );
         undef $returncode;
-        $self->{'headers_include_space'} = ($protocol_reply & SMFIP_HDR_LEADSPC) != 0;
     }
     elsif ( $command eq SMFIC_RCPT ) {
         my $envrcpt = $self->milter_split_buffer( $buffer );
@@ -126,34 +121,14 @@ sub milter_process_command {
         $self->fatal("Unknown milter command $command");
     }
 
-    my $config = $self->{'config'};
-
     my $reject_reason;
-    my $defer_reason;
-    my $quarantine_reason;
     if ( $reject_reason = $handler->get_reject_mail() ) {
         $handler->clear_reject_mail();
         $returncode = SMFIS_REJECT;
     }
-    elsif ( $defer_reason = $handler->get_defer_mail() ) {
-        $handler->clear_defer_mail();
-        $returncode = SMFIS_TEMPFAIL;
-    }
-    elsif ( $quarantine_reason = $handler->get_quarantine_mail() ) {
-        if ( $config->{'milter_quarantine'} ) {
-            $handler->clear_quarantine_mail();
-            $returncode = SMFIR_QUARANTINE;
-        }
-        else {
-            undef $quarantine_reason;
-        }
-    }
 
     if (defined $returncode) {
-        if ( $returncode eq SMFIR_QUARANTINE ) {
-            # NOP
-        }
-        elsif ( $returncode == SMFIS_CONTINUE ) {
+        if ( $returncode == SMFIS_CONTINUE ) {
             $returncode = SMFIR_CONTINUE;
         }
         elsif ( $returncode == SMFIS_TEMPFAIL ) {
@@ -170,6 +145,7 @@ sub milter_process_command {
             $handler->metric_count( 'mail_processed_total', { 'result' => 'accepted' } );
         }
 
+        my $config = $self->{'config'};
         if ( $config->{'dryrun'} ) {
             if ( $returncode ne SMFIR_CONTINUE ) {
                 $self->loginfo ( "dryrun returncode changed from $returncode to continue" );
@@ -180,7 +156,7 @@ sub milter_process_command {
         if ( $command ne SMFIC_ABORT ) {
             if ( $reject_reason ) {
                 my ( $rcode, $xcode, $message ) = split( ' ', $reject_reason, 3 );
-                if ($rcode !~ /^[5]\d\d$/ || $xcode !~ /^[5]\.\d\.\d$/ || substr($rcode, 0, 1) ne substr($xcode, 0, 1)) {
+                if ($rcode !~ /^[45]\d\d$/ || $xcode !~ /^[45]\.\d\.\d$/ || substr($rcode, 0, 1) ne substr($xcode, 0, 1)) {
                     $handler->metric_count( 'mail_processed_total', { 'result' => 'deferred_error' } );
                     $self->loginfo ( "Invalid reject message $reject_reason - setting to TempFail" );
                     $self->write_packet(SMFIR_TEMPFAIL );
@@ -194,35 +170,13 @@ sub milter_process_command {
                     );
                 }
             }
-            elsif ( $defer_reason ) {
-                my ( $rcode, $xcode, $message ) = split( ' ', $defer_reason, 3 );
-                if ($rcode !~ /^[4]\d\d$/ || $xcode !~ /^[4]\.\d\.\d$/ || substr($rcode, 0, 1) ne substr($xcode, 0, 1)) {
-                    $handler->metric_count( 'mail_processed_total', { 'result' => 'deferred_error' } );
-                    $self->loginfo ( "Invalid defer message $defer_reason - setting to TempFail" );
-                    $self->write_packet(SMFIR_TEMPFAIL );
-                }
-                else {
-                    $handler->metric_count( 'mail_processed_total', { 'result' => 'deferred' } );
-                    $self->loginfo ( "SMTPDefer: $reject_reason" );
-                    $self->write_packet( SMFIR_REPLYCODE,
-                        $defer_reason
-                        . "\0"
-                    );
-                }
-            }
-            elsif ( $quarantine_reason ) {
-                $handler->metric_count( 'mail_processed_total', { 'result' => 'quarantined' } );
-                $self->loginfo ( "SMTPQuarantine: $quarantine_reason" );
-                $self->write_packet( SMFIR_QUARANTINE,
-                    $quarantine_reason
-                    . "\0"
-                );
-            }
             else {
                 $self->write_packet($returncode);
             }
         }
     }
+
+    return;
 }
 
 sub milter_process_connect {
@@ -287,41 +241,38 @@ sub milter_split_buffer {
 
 sub add_header {
     my ( $self, $header, $value ) = @_;
-    $value =~ s/\015\012/\012/g;
     $self->write_packet( SMFIR_ADDHEADER,
         $header
         . "\0"
-        . ($self->{'headers_include_space'} ? ' ' : '')
         . $value
         . "\0"
     );
+    return;
 }
 
 sub change_header {
     my ( $self, $header, $index, $value ) = @_;
     $value = '' unless defined($value);
-    $value =~ s/\015\012/\012/g;
     $self->write_packet( SMFIR_CHGHEADER,
         pack('N', $index)
         . $header
         . "\0"
-        . ($self->{'headers_include_space'} ? ' ' : '')
         . $value
         . "\0"
     );
+    return;
 }
 
 sub insert_header {
     my ( $self, $index, $key, $value ) = @_;
-    $value =~ s/\015\012/\012/g;
     $self->write_packet( SMFIR_INSHEADER,
         pack( 'N', $index )
         . $key
         . "\0"
-        . ($self->{'headers_include_space'} ? ' ' : '')
         . $value
         . "\0"
     );
+    return;
 }
 
 sub write_packet {
@@ -333,6 +284,7 @@ sub write_packet {
     $socket->syswrite($len);
     $socket->syswrite($code);
     $socket->syswrite($data);
+    return;
 }
 
 1;
@@ -345,11 +297,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Protocol::Milter - Milter protocol handling
+Mail::Milter::Authentication::Protocol::Milter
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -412,13 +364,18 @@ Receive a new command from the protocol stream and process it.
 
 =back
 
+=head1 DEPENDENCIES
+
+  English
+  Net::IP
+
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
