@@ -1,16 +1,19 @@
 package Mail::Milter::Authentication::Protocol::SMTP;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: SMTP protocol handling
-our $VERSION = '2.20210105.2'; # VERSION
-use Digest::MD5 qw{ md5_hex };
+our $VERSION = '2.20180318'; # VERSION
+
+use English qw{ -no_match_vars };
 use Email::Date::Format qw{ email_date };
+use IO::Socket;
 use IO::Socket::INET;
 use IO::Socket::UNIX;
-use IO::Socket;
+use Digest::MD5 qw{ md5_hex };
 use Net::IP;
+use Sys::Syslog qw{:standard :macros};
+
+use Mail::Milter::Authentication::Constants qw{ :all };
+use Mail::Milter::Authentication::Config;
 
 sub register_metrics {
     return {
@@ -43,6 +46,7 @@ sub smtp_status {
     my ( $self, $status ) = @_;
     my $smtp = $self->{'smtp'};
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':' . $status . '(' . $self->{'count'} . '.' . $smtp->{'count'} . ')';
+    return;
 }
 
 sub smtp_init {
@@ -63,6 +67,8 @@ sub smtp_init {
     $handler->dbgout( 'SMTP Transaction count', $self->{'count'} . '.' . $smtp->{'count'} , LOG_INFO );
 
     $smtp->{'init_required'} = 0;
+
+    return;
 }
 
 sub protocol_process_request {
@@ -71,10 +77,6 @@ sub protocol_process_request {
     my $handler = $self->{'handler'}->{'_Handler'};
     $handler->top_setup_callback();
 
-    my $config = $self->{ 'config' };
-    my $seconds = $config->{'content_timeout'} // 300;
-    $handler->set_overall_timeout( $seconds * 1000000 );
-
     $self->{'smtp'} = {
         'fwd_helo_host'    => undef,
         'fwd_connect_ip'   => undef,
@@ -179,7 +181,6 @@ sub protocol_process_request {
             $self->smtp_command_rset( $command );
         }
         elsif ( $uccommand =~ /^DATA/ ) {
-            $handler->set_overall_timeout( $seconds * 1000000 );
             $self->smtp_command_data( $command );
         }
         elsif ( $uccommand =~ /^QUIT/ ){
@@ -194,13 +195,13 @@ sub protocol_process_request {
         }
 
     }
-    $handler->clear_overall_timeout();
 
     $self->smtp_status('smtp.close');
 
     $self->close_destination_socket();
 
     delete $self->{'smtp'};
+    return;
 }
 
 sub smtp_queue_id {
@@ -222,44 +223,6 @@ sub command_param {
     return $p;
 }
 
-# Splits the given command parameter line into a list of separate
-# path (<foo@example.com>) and esmtp-param (KEYWORD=VALUE) strings.
-sub split_command_params {
-    my ( $line ) = @_;
-    $line =~ s/^\s+//;
-    my $path_end = find_path_end( $line ) || length( $line );
-    my $path = substr( $line, 0, $path_end );
-    $line = substr( $line, $path_end );
-    $line =~ s/^\s+//;
-    return ( $path, split( /\s+/, $line ) );
-}
-
-sub find_path_end {
-    my ( $input ) = @_;
-    my $len = length( $input );
-    my @qstack;
-    for ( my $i = 0; $i < $len; $i++ ) {
-        my $c = substr( $input, $i, 1 );
-        if ( @qstack && $c eq $qstack[-1] ) {
-            # end of a quoted string
-            pop @qstack;
-        } elsif ( $c eq '"' ) {
-            # start of a "" quoted string
-            push @qstack, '"';
-        } elsif ( $c eq '<' && ( !@qstack || $qstack[-1] eq '>' ) ) {
-            # start of a <> quoted string (possibly inside of another <>)
-            push @qstack, '>';
-        } elsif ( $c eq '\\' && @qstack ) {
-            # escaped character within a quoted string
-            $i++;
-        } elsif ( $c eq ' ' && !@qstack ) {
-            # found the end
-            return $i;
-        }
-    }
-    return ( @qstack ? undef : $len );
-}
-
 sub smtp_command_lhlo {
     my ( $self, $command ) = @_;
     my $smtp = $self->{'smtp'};
@@ -285,6 +248,7 @@ sub smtp_command_lhlo {
     print $socket "250-PIPELINING\r\n";
     print $socket "250-ENHANCEDSTATUSCODES\r\n";
     print $socket "250 8BITMIME\r\n";
+    return;
 }
 
 sub smtp_command_ehlo {
@@ -310,6 +274,7 @@ sub smtp_command_ehlo {
     print $socket "250-PIPELINING\r\n";
     print $socket "250-ENHANCEDSTATUSCODES\r\n";
     print $socket "250 8BITMIME\r\n";
+    return;
 }
 
 sub smtp_command_helo {
@@ -326,6 +291,7 @@ sub smtp_command_helo {
     }
     $smtp->{'helo_host'} = command_param( $command,5 );
     print $socket "250 " . $smtp->{'server_name'} . " Hi " . $smtp->{'helo_host'} . "\r\n";
+    return;
 }
 
 sub smtp_command_xforward {
@@ -371,6 +337,7 @@ sub smtp_command_xforward {
         }
     }
     print $socket "250 2.0.0 Ok\r\n";
+    return;
 }
 
 sub smtp_command_rset {
@@ -396,15 +363,8 @@ sub smtp_command_rset {
     $self->smtp_init();
 
     my $smtp_conf = $self->get_smtp_config();
-
     my $handler = $self->{'handler'}->{'_Handler'};
-    if ( $handler->{'exit_on_close'} ) {
-            $smtp->{'last_command'} = 1;
-            $handler->dbgout( 'EXIT ON CLOSE REQUESTED', 'closing on RSET', LOG_INFO );
-            print $socket "421 4.3.2 Pipeline limit reached\r\n";
-            return;
-    }
-    if ( $smtp_conf->{'pipeline_limit'} ) {
+        if ( $smtp_conf->{'pipeline_limit'} ) {
         my $count = $smtp->{'count'};
         my $limit = $smtp_conf->{'pipeline_limit'};
         if ( $count > $limit ) {
@@ -415,6 +375,8 @@ sub smtp_command_rset {
         }
     }
     print $socket "250 2.0.0 Ok\r\n";
+
+    return;
 }
 
 sub smtp_command_mailfrom {
@@ -445,18 +407,15 @@ sub smtp_command_mailfrom {
         $ip = substr( $ip, 5 );
     }
 
-    # Do connection remapping first
-    $handler->remap_connect_callback( $host, Net::IP->new( $ip ) );
-    $handler->remap_helo_callback( $helo );
-
-    $self->logdebug( "Inbound IP Address " . $handler->{'ip_object'}->ip() );
-    $returncode = $handler->top_connect_callback( $host, $handler->{'ip_object'} );
+    $self->logdebug( "Inbound IP Address $ip" );
+    $returncode = $handler->top_connect_callback( $host, Net::IP->new( $ip ) );
     if ( $returncode == SMFIS_CONTINUE ) {
-        $returncode = $handler->top_helo_callback( $handler->{'helo_name'} );
+        $returncode = $handler->top_helo_callback( $helo );
         if ( $returncode == SMFIS_CONTINUE ) {
             my $envfrom = command_param( $command,10 );
             $smtp->{'mail_from'} = $envfrom;
-            $returncode = $handler->top_envfrom_callback( split_command_params( $envfrom ) );
+            $envfrom =~ s/ BODY=8BITMIME$//;
+            $returncode = $handler->top_envfrom_callback( $envfrom );
             if ( $returncode == SMFIS_CONTINUE ) {
                 $smtp->{'has_mail_from'} = 1;
                 print $socket "250 2.0.0 Ok\r\n";
@@ -466,11 +425,6 @@ sub smtp_command_mailfrom {
                 $self->loginfo ( "SMTPReject: $reject_reason" );
                 print $socket $reject_reason . "\r\n";
             }
-            elsif ( my $defer_reason = $handler->get_defer_mail() ) {
-                $handler->clear_defer_mail();
-                $self->loginfo ( "SMTPDefer: $defer_reason" );
-                print $socket $defer_reason . "\r\n";
-            }
             else {
                 print $socket "451 4.0.0 MAIL - That's not right\r\n";
             }
@@ -480,11 +434,6 @@ sub smtp_command_mailfrom {
             $self->loginfo ( "SMTPReject: $reject_reason" );
             print $socket $reject_reason . "\r\n";
         }
-        elsif ( my $defer_reason = $handler->get_defer_mail() ) {
-            $handler->clear_defer_mail();
-            $self->loginfo ( "SMTPDefer: $defer_reason" );
-            print $socket $defer_reason . "\r\n";
-        }
         else {
             print $socket "451 4.0.1 HELO - That's not right\r\n";
         }
@@ -494,14 +443,11 @@ sub smtp_command_mailfrom {
         $self->loginfo ( "SMTPReject: $reject_reason" );
         print $socket $reject_reason . "\r\n";
     }
-    elsif ( my $defer_reason = $handler->get_defer_mail() ) {
-        $handler->clear_defer_mail();
-        $self->loginfo ( "SMTPDefer: $defer_reason" );
-        print $socket $defer_reason . "\r\n";
-    }
     else {
         print $socket "451 4.0.2 Connection - That's not right\r\n";
     }
+
+    return;
 }
 
 sub smtp_command_rcptto {
@@ -518,7 +464,7 @@ sub smtp_command_rcptto {
     }
     my $envrcpt = command_param( $command,8 );
     push @{ $smtp->{'rcpt_to'} }, $envrcpt;
-    my $returncode = $handler->top_envrcpt_callback( split_command_params( $envrcpt ) );
+    my $returncode = $handler->top_envrcpt_callback( $envrcpt );
     if ( $returncode == SMFIS_CONTINUE ) {
         push @{ $smtp->{'lmtp_rcpt'} }, $envrcpt;
         print $socket "250 2.0.0 Ok\r\n";
@@ -528,14 +474,11 @@ sub smtp_command_rcptto {
         $self->loginfo ( "SMTPReject: $reject_reason" );
         print $socket $reject_reason . "\r\n";
     }
-    elsif ( my $defer_reason = $handler->get_defer_mail() ) {
-        $handler->clear_defer_mail();
-        $self->loginfo ( "SMTPDefer: $defer_reason" );
-        print $socket $defer_reason . "\r\n";
-    }
     else {
         print $socket "451 4.0.3 That's not right\r\n";
     }
+
+    return;
 }
 
 sub smtp_command_data {
@@ -598,14 +541,10 @@ sub smtp_command_data {
             if ( $value ) {
                 push @{ $smtp->{'headers'} } , $value;
                 my ( $hkey, $hvalue ) = split ( ':', $value, 2 );
-                $hvalue =~ s/^\s+//;
-                $hkey =~ s/^\s+//;
-                $hkey =~ s/\s+$//;
-                if ( ! $fail ) {
-                    my $returncode = $handler->top_header_callback( $hkey, $hvalue, $value );
-                    if ( $returncode != SMFIS_CONTINUE ) {
-                        $fail = 1;
-                    }
+                $hvalue =~ s/^ //;
+                my $returncode = $handler->top_header_callback( $hkey, $hvalue );
+                if ( $returncode != SMFIS_CONTINUE ) {
+                    $fail = 1;
                 }
             }
             $value = $header_line;
@@ -614,40 +553,18 @@ sub smtp_command_data {
     if ( $value ) {
         push @{ $smtp->{'headers'} } , $value;
         my ( $hkey, $hvalue ) = split ( ':', $value, 2 );
-        $hvalue =~ s/^\s+//;
-        $hkey =~ s/^\s+//;
-        $hkey =~ s/\s+$//;
-        if ( ! $fail ) {
-            my $returncode = $handler->top_header_callback( $hkey, $hvalue, $value );
-            if ( $returncode != SMFIS_CONTINUE ) {
-                $fail = 1;
-            }
-        }
-    }
-    if ( ! $fail ) {
-        $returncode = $handler->top_eoh_callback();
+        $hvalue =~ s/^ //;
+        my $returncode = $handler->top_header_callback( $hkey, $hvalue );
         if ( $returncode != SMFIS_CONTINUE ) {
             $fail = 1;
         }
     }
-
-    my $smtp_conf = $self->get_smtp_config();
-
-    my $chunk_limit = 1048576; # Process in chunks no larger than...
-    if ( exists ( $smtp_conf->{ 'chunk_limit' } ) ) {
-        $chunk_limit = $smtp_conf->{ 'chunk_limit' };
-    }
-
-    my $temp_file;
-    if ( exists ( $smtp_conf->{ 'temp_dir' } ) ) {
-        # TODO use spool_dir to create this
-        # add config option to en/disable this
-        # allow dir to be overridden
-        $temp_file = File::Temp->new( DIR => $smtp_conf->{ 'temp_dir' } );
+    $returncode = $handler->top_eoh_callback();
+    if ( $returncode != SMFIS_CONTINUE ) {
+        $fail = 1;
     }
 
     $self->smtp_status('smtp.i.body');
-    my $body_chunk = q{};
     if ( ! $done ) {
         eval {
             alarm( $smtp->{'smtp_timeout_in'} );
@@ -660,32 +577,12 @@ sub smtp_command_data {
                 if ( $dataline =~ /^\./ ) {
                     $dataline = substr( $dataline, 1 );
                 }
-
-                if ( $temp_file ) {
-                    print $temp_file $dataline;
-                }
-                else {
-                   $body .= $dataline;
-                }
-
-                if ( length( $body_chunk ) + length( $dataline ) > $chunk_limit ) {
-                    $returncode = $handler->top_body_callback( $body_chunk );
-                    if ( $returncode != SMFIS_CONTINUE ) {
-                        $fail = 1;
-                    }
-                    $body_chunk = q{};
-                }
-
-                $body_chunk .= $dataline;
-
+                $body .= $dataline;
                 alarm( $smtp->{'smtp_timeout_in'} );
             }
-            if ( ! $fail ) {
-                $returncode = $handler->top_body_callback( $body_chunk );
-                if ( $returncode != SMFIS_CONTINUE ) {
-                    $fail = 1;
-                }
-                $body_chunk = q{};
+            $returncode = $handler->top_body_callback( $body );
+            if ( $returncode != SMFIS_CONTINUE ) {
+                $fail = 1;
             }
         };
         if ( my $error = $@ ) {
@@ -696,33 +593,18 @@ sub smtp_command_data {
         alarm( 0 );
     }
 
-    if ( ! $fail ) {
-        $returncode = $handler->top_eom_callback();
-        if ( $returncode != SMFIS_CONTINUE ) {
-            $fail = 1;
-        }
+    $returncode = $handler->top_eom_callback();
+    if ( $returncode != SMFIS_CONTINUE ) {
+        $fail = 1;
     }
-
     $self->smtp_status('smtp.i.data.received');
 
     if ( ! $fail ) {
-
-        if ( $temp_file ) {
-            $smtp->{'spool'} = $temp_file;
-        }
-        else {
-            $smtp->{'body'} = $body;
-        }
+        $smtp->{'body'} = $body;
 
         if ( $self->smtp_forward_to_destination() ) {
 
-            if ( my $reject_reason = $handler->get_quarantine_mail() ) {
-                $handler->metric_count( 'mail_processed_total', { 'result' => 'quarantined' } );
-            }
-            else {
-                $handler->metric_count( 'mail_processed_total', { 'result' => 'accepted' } );
-            }
-
+            $handler->metric_count( 'mail_processed_total', { 'result' => 'accepted' } );
             $handler->dbgout( 'Accept string', $smtp->{'string'}, LOG_INFO );
             $smtp->{'has_data'} = 1;
 
@@ -776,20 +658,6 @@ sub smtp_command_data {
             print $socket $reject_reason . "\r\n";
         }
     }
-    elsif ( my $defer_reason = $handler->get_defer_mail() ) {
-        $handler->metric_count( 'mail_processed_total', { 'result' => 'defered' } );
-        $handler->clear_defer_mail();
-        if ( $smtp->{'using_lmtp'} ) {
-            foreach my $rcpt_to ( @{ $smtp->{'lmtp_rcpt'} } ) {
-                $self->loginfo ( "SMTPDefer: $defer_reason" );
-                print $socket $defer_reason . "\r\n";
-            }
-        }
-        else {
-            $self->loginfo ( "SMTPDefer: $defer_reason" );
-            print $socket $defer_reason . "\r\n";
-        }
-    }
     else {
         $handler->metric_count( 'mail_processed_total', { 'result' => 'deferred_error' } );
         if ( $smtp->{'using_lmtp'} ) {
@@ -816,11 +684,7 @@ sub smtp_command_data {
     $smtp->{'string'}           = q{};
     $self->{'handler'}->{'_Handler'}->top_close_callback();
     $smtp->{'init_required'}    = 1;
-
-    if ( $handler->{'exit_on_close'} ) {
-            $smtp->{'last_command'} = 1;
-            $handler->dbgout( 'EXIT ON CLOSE REQUESTED', 'NO MORE SMTP', LOG_INFO );
-    }
+    return;
 }
 
 sub smtp_insert_received_header {
@@ -856,6 +720,7 @@ sub smtp_insert_received_header {
     );
 
     splice @{ $smtp->{'headers'} }, 0, 0, 'Received: '. $value;
+    return;
 }
 
 sub smtp_forward_to_destination {
@@ -960,32 +825,14 @@ sub smtp_forward_to_destination {
     }
     $email .= "\r\n";
 
-    my $spool = $smtp->{'spool'};
-    if ( $spool ) {
+    my $body = $smtp->{'body'};
+    $body =~ s/\015?\012/\015\012/g;
+    $email .= $body;
 
-        # Handle transparency - should not be any in headers, but for completeness
-        $email =~ s/\015\012\./\015\012\.\./g;
+    # Handle transparency
+    $email =~ s/\015\012\./\015\012\.\./g;
 
-        print $sock $email;
-
-        seek( $spool, 0, 0 );
-        while ( my $line = <$spool> ) {
-            $line =~ s/\015?\012/\015\012/g;
-            $line =~ s/^\./\.\./g;
-            print $sock $line;
-        }
-
-    }
-    else {
-        my $body = $smtp->{'body'};
-        $body =~ s/\015?\012/\015\012/g;
-        $email .= $body;
-
-        # Handle transparency
-        $email =~ s/\015\012\./\015\012\.\./g;
-
-        print $sock $email;
-    }
+    print $sock $email;
 
     $self->logdebug( 'Sending end to destination' );
     $self->send_smtp_packet( $sock, '.',    '250' ) || return;
@@ -1003,6 +850,7 @@ sub close_destination_socket {
     $self->send_smtp_packet( $sock, 'QUIT', '221' ) || return;
     $sock->close();
     delete $smtp->{'destination_sock'};
+    return;
 }
 
 sub send_smtp_packet {
@@ -1056,6 +904,7 @@ sub add_header {
     my $smtp = $self->{'smtp'};
     $value =~ s/\015?\012/\015\012/g;
     push @{ $smtp->{'headers'} } , "$header: $value";
+    return;
 }
 
 sub change_header {
@@ -1088,6 +937,8 @@ sub change_header {
             #untested.
         }
     }
+
+    return;
 }
 
 sub insert_header {
@@ -1095,6 +946,7 @@ sub insert_header {
     my $smtp = $self->{'smtp'};
     $value =~ s/\015?\012/\015\012/g;
     splice @{ $smtp->{'headers'} }, $index - 1, 0, "$key: $value";
+    return;
 }
 
 1;
@@ -1107,11 +959,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Protocol::SMTP - SMTP protocol handling
+Mail::Milter::Authentication::Protocol::SMTP
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -1234,13 +1086,19 @@ Update the process name status line
 
 =back
 
+=head1 DEPENDENCIES
+
+  English
+  Digest::MD5
+  Net::IP
+
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
