@@ -1,24 +1,27 @@
 package Mail::Milter::Authentication::Tester;
-use 5.20.0;
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Class used for testing
-our $VERSION = '2.20210105.2'; # VERSION
-use Mail::Milter::Authentication;
-use Mail::Milter::Authentication::Client;
-use Mail::Milter::Authentication::Protocol::Milter;
-use Mail::Milter::Authentication::Protocol::SMTP;
-use Cwd qw{ cwd };
-use IO::Socket::INET;
-use IO::Socket::UNIX;
-use Net::DNS::Resolver::Mock 1.20171219;
-use Test::File::Contents;
-use Test::More;
+our $VERSION = '2.20180318'; # VERSION
 
 our @ISA = qw{ Exporter }; ## no critic
 our @EXPORT = qw{ start_milter stop_milter get_metrics test_metrics smtp_process smtp_process_multi milter_process smtpput send_smtp_packet smtpcat }; ## no critic
 
+use Net::DNS::Resolver::Mock 1.20171219;
+use Test::More;
+use Test::File::Contents;
+
+use Cwd qw{ cwd };
+use IO::Socket::INET;
+use IO::Socket::UNIX;
+use JSON;
+use Module::Load;
+
+use Mail::Milter::Authentication;
+use Mail::Milter::Authentication::Client;
+use Mail::Milter::Authentication::Config;
+use Mail::Milter::Authentication::Protocol::Milter;
+use Mail::Milter::Authentication::Protocol::SMTP;
+
 my $base_dir = cwd();
 
 our $MASTER_PROCESS_PID = $$;
@@ -115,7 +118,7 @@ sub test_metrics {
     subtest $expected => sub {
 
         my $metrics =  get_metrics( 'tmp/authentication_milter_test_metrics.sock' );
-        my $j = JSON::XS->new();
+        my $j = JSON->new();
 
         if ( -e $expected ) {
 
@@ -128,19 +131,13 @@ sub test_metrics {
 
             foreach my $key ( sort keys %$data ) {
                 if ( $key =~ /seconds_total/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
+                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $key" );
                 }
                 elsif ( $key =~ /microseconds_sum/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
-                }
-                elsif ( $key =~ /authmilter_forked_children_total/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
-                }
-                elsif ( $key =~ /authmilter_processes_/) {
-                    is( $metrics->{ $key } > -1, $data->{ $key } > -1, "Metrics $expected $key" );
+                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $key" );
                 }
                 else {
-                    is( $metrics->{ $key }, $data->{ $key }, "Metrics $expected $key" );
+                    is( $metrics->{ $key }, $data->{ $key }, "Metrics $key" );
                 }
             }
 
@@ -157,12 +154,6 @@ sub test_metrics {
                 elsif ( $key =~ /microseconds_sum/ ) {
                     $metrics->{ $key } = 123456 if $metrics->{ $key } > 0;
                 }
-                elsif ( $key =~ /authmilter_forked_children_total/ ) {
-                    $metrics->{ $key } = 123456 if $metrics->{ $key } > 0;
-                }
-                elsif ( $key =~ /authmilter_processes_/) {
-                    $metrics->{ $key } = 123456 if $metrics->{ $key } > -1;
-                }
             }
             open my $OutF, '>', $expected;
             $j->pretty();
@@ -172,6 +163,8 @@ sub test_metrics {
         }
 
     };
+
+    return;
 }
 
 sub smtp_process {
@@ -217,6 +210,8 @@ sub smtp_process {
     else {
         is( $return, 1, 'SMTP Put Returned ok' );
     }
+
+    return;
 }
 
 sub smtp_process_multi {
@@ -278,6 +273,8 @@ sub smtp_process_multi {
     waitpid( $cat_pid,0 );
 
     files_eq_or_diff( 'data/example/' . $args->{'dest'}, 'tmp/result/' . $args->{'dest'}, 'smtp ' . $args->{'desc'} );
+
+    return;
 }
 
 sub milter_process {
@@ -303,6 +300,8 @@ sub milter_process {
     });
 
     files_eq_or_diff( 'data/example/' . $args->{'dest'}, 'tmp/result/' . $args->{'dest'}, 'milter ' . $args->{'desc'} );
+
+    return;
 }
 
 sub smtpput {
@@ -557,6 +556,7 @@ sub client {
 
     }
     waitpid( $pid, 0 );
+    return;
 }
 
 1;
@@ -569,11 +569,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Tester - Class used for testing
+Mail::Milter::Authentication::Tester
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 AUTHOR
 
@@ -581,7 +581,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
