@@ -1,13 +1,20 @@
 package Mail::Milter::Authentication::Tester::HandlerTester;
-use 5.20.0;
+
 use strict;
 use warnings;
-use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Class for testing handlers
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20180318'; # VERSION
+
+use Carp;
+use Clone qw{ clone };
+use English qw{ -no_match_vars };
+use Mail::AuthenticationResults::Header;
+use Mail::AuthenticationResults::Header::AuthServID;
 use Mail::Milter::Authentication;
+use Mail::Milter::Authentication::Config qw{ set_config get_config default_config };
+use Mail::Milter::Authentication::Constants qw{ :all };
 use Mail::Milter::Authentication::Protocol::Milter;
 use Mail::Milter::Authentication::Protocol::SMTP;
+use Module::Load;
 use Net::DNS::Resolver::Mock;
 use Net::IP;
 
@@ -31,8 +38,8 @@ sub _build_config_smtp {
         'tempfail_on_error_local'         => 1,
         'tempfail_on_error_trusted'       => 1,
 
-        '#metric_connection'               => 'unix:tmp/authentication_milter_test_metrics.sock',
-        '#metric_umask'                    => '0000',
+        'metric_connection'               => 'unix:tmp/authentication_milter_test_metrics.sock',
+        'metric_umask'                    => '0000',
 
         'protocol' => 'smtp',
         'smtp' => {
@@ -68,8 +75,8 @@ sub _build_config_milter {
         'tempfail_on_error_local'         => 1,
         'tempfail_on_error_trusted'       => 1,
 
-        '#metric_connection'               => 'unix:tmp/authentication_milter_test_metrics.sock',
-        '#metric_umask'                    => '0000',
+        'metric_connection'               => 'unix:tmp/authentication_milter_test_metrics.sock',
+        'metric_umask'                    => '0000',
 
         'protocol' => 'milter',
 
@@ -107,8 +114,6 @@ sub new {
     }
 
     $Mail::Milter::Authentication::Config::PREFIX = $self->{ 'prefix' };
-    Mail::Milter::Authentication::Config::setup_config;
-
     my $config = get_config();
 
     my $Resolver = Net::DNS::Resolver::Mock->new();
@@ -177,6 +182,7 @@ sub snapshot {
     my ( $self, $name ) = @_;
     my $snapshot = clone( $self->{ 'authmilter' } );
     $self->{ 'snapshots' }->{ $name } = $snapshot;
+    return;
 }
 
 sub switch {
@@ -184,6 +190,7 @@ sub switch {
     croak 'unknown snapshot' if ! exists ( $self->{ 'snapshots' }->{ $name } );
     my $snapshot = clone( $self->{ 'snapshots' }->{ $name } );
     $self->{ 'authmilter' } = $snapshot;
+    return;
 }
 
 sub handler {
@@ -197,14 +204,12 @@ sub connect { ## no critic
     my $ip_obj = eval{ Net::IP->new( $ip ) } // undef;
     # An undef here should not make it through to handlers, however
     # for testing we will allow this.
-    $self->handler()->remap_connect_callback( $name, $ip_obj );
-    return $self->handler()->top_connect_callback( $name, $self->handler()->{ 'ip_object' } );
+    return $self->handler()->top_connect_callback( $name, $ip_obj );
 }
 
 sub helo {
     my ( $self, $helo ) = @_;
-    $self->handler()->remap_helo_callback( $helo );
-    return $self->handler()->top_helo_callback( $self->handler()->{ 'helo_name' } );
+    return $self->handler()->top_helo_callback( $helo );
 }
 
 sub mailfrom {
@@ -218,9 +223,8 @@ sub rcptto {
 }
 
 sub header {
-    my ( $self, $key, $value, $original ) = @_;
-    $original = "$key: $value" if ! defined $original;
-    return $self->handler()->top_header_callback( $key, $value, $original );
+    my ( $self, $key, $value ) = @_;
+    return $self->handler()->top_header_callback( $key, $value );
 }
 
 sub end_of_headers {
@@ -315,6 +319,8 @@ sub run {
 
     $self->addheader();
     #    $self->close();
+
+    return;
 }
 
 sub get_return {
@@ -340,7 +346,6 @@ sub get_authresults_header {
     my @added_ar_headers = ( @{ $c_auth_headers }, @{ $auth_headers } );
     my $header = Mail::AuthenticationResults::Header->new()->set_value( Mail::AuthenticationResults::Header::AuthServID->new()->set_value( $self->servername() ) );
     foreach my $ar_header ( @added_ar_headers ) {
-        eval{ $ar_header->orphan(); }; # Remove parent for testing.
         $header->add_child( $ar_header );
     }
     return $header;
@@ -356,11 +361,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Tester::HandlerTester - Class for testing handlers
+Mail::Milter::Authentication::Tester::HandlerTester
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -580,7 +585,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Marc Bradshaw.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
